"""
Provides the gfts routes file with route information. last update: 2020-02-22
"""

LINE_CSV_FILE = """\
route_id,route_short_name,route_long_name,route_desc,route_type,route_url,route_color,route_text_color
2,1,"GARE DE L'OUEST - STOCKEL",,1,,C4008F,FFFFFF
3,2,"SIMONIS - ELISABETH",,1,,F57000,FFFFFF
5,3,"ESPLANADE - CHURCHILL",,0,,B5BA05,000000
8,4,"GARE DU NORD - STALLE (P)",,0,,F25482,000000
1,5,"ERASME - HERRMANN-DEBROUX",,1,,E6B012,FFFFFF
4,6,"ROI BAUDOUIN - ELISABETH",,1,,0078AD,FFFFFF
6,7,"VANDERKINDERE - HEYSEL",,0,,FFF06E,000000
9,8,"LOUISE - ROODEBEEK",,0,,00A1DF,000000
10,9,"SIMONIS - ARBRE BALLON",,0,,DB3EB1,000000
66,12,"BRUSSELS AIRPORT - BRUSSELS CITY",,3,,338C26,FFFFFF
23,13,"ETANGS NOIRS - UZ-VUB",,3,,9EBFE3,000000
24,14,"HEYSEL - GARE DU NORD",,3,,FF9EC2,000000
47,17,"BEAULIEU - HEILIGENBORRE",,3,,DE3B21,FFFFFF
12,19,"GROOT-BIJGAARDEN - DE WAND",,0,,DE3B21,FFFFFF
25,20,"HUNDERENVELD - GARE DU NORD",,3,,E3BA12,000000
72,21,"MAES - LUXEMBOURG",,3,,F7E017,000000
14,25,"BOONDAEL GARE - ROGIER",,0,,991F36,FFFFFF
48,27,"GARE DU MIDI - ANDROMEDE",,3,,9EBFE3,000000
65,27,"GARE DU MIDI - PLEIADES",,3,,9EBFE3,000000
49,28,"BRABANCONNE - KONKEL",,3,,DE3B21,FFFFFF
67,29,"DE BROUCKERE - HOF TEN BERG",,3,,E87D0D,FFFFFF
22,32,"DA VINCI - DROGENBOS CHATEAU",,0,,F7E017,000000
27,33,"DANSAERT - LOUISE",,3,,FF9EC2,000000
50,34,"PORTE DE NAMUR - SAINTE-ANNE",,3,,E3BA12,000000
51,36,"SCHUMAN - KONKEL",,3,,9EBFE3,000000
28,37,"ALBERT - GARE DE LINKEBEEK",,3,,36578C,FFFFFF
52,38,"GARE CENTRALE - HEROS",,3,,B085B3,FFFFFF
17,39,"MONTGOMERY - BAN-EIK",,0,,DE3B21,FFFFFF
53,41,"HEROS - TRANSVAAL",,3,,9EBFE3,000000
69,42,"VIADUC E40 - ROODEBEEK",,3,,338C26,FFFFFF
29,43,"OBSERVATOIRE - VIVIER D'OIE",,3,,996308,FFFFFF
16,44,"MONTGOMERY - TERVUREN STATION",,0,,E3BA12,000000
70,45,"ROODEBEEK - SAINT-VINCENT",,3,,B085B3,FFFFFF
30,46,"MOORTEBEEK - GLIBERT",,3,,DE3B21,FFFFFF
87,47,"DE BROUCKERE - VILVOORDE STATION",,3,,B085B3,FFFFFF
90,47,"HEEMBEEK - VILVOORDE STATION",,3,,B085B3,FFFFFF
83,48,"ANNEESSENS - DECROLY",,3,,338C26,FFFFFF
33,49,"GARE DU MIDI - SIMONIS",,3,,36578C,FFFFFF
34,50,"GARE DU MIDI - LOT STATION",,3,,B5BA05,000000
13,51,"STADE - VAN HAELEN",,0,,E3BA12,000000
88,53,"WESTLAND SHOPPING - HOPITAL MILITAIRE",,3,,338C26,FFFFFF
35,54,"TRONE - FOREST (BERVOETS)",,3,,DE3B21,FFFFFF
15,55,"DA VINCI - ROGIER",,0,,E3BA12,000000
91,56,"SCHUMAN - BUDA",,3,,E87D0D,FFFFFF
89,57,"GARE DU NORD - HOPITAL MILITAIRE",,3,,DE3B21,FFFFFF
74,58,"VILVOORDE STATION - YSER",,3,,338C26,FFFFFF
75,59,"HOPITAL ETTERBEEK-IXELLES - BORDET STATION",,3,,996308,FFFFFF
54,60,"AMBIORIX - UCCLE CALEVOET",,3,,FF9EC2,000000
55,61,"GARE DU NORD - MONTGOMERY",,3,,F7E017,000000
7,62,"EUROCONTROL - CIMETIERE DE JETTE",,0,,FF9EC2,000000
76,63,"GARE CENTRALE - CIMETIERE DE BRUXELLES",,3,,9EBFE3,000000
78,64,"PORTE DE NAMUR - BORDET STATION",,3,,DE3B21,FFFFFF
77,65,"GARE CENTRALE - MACHELEN",,3,,E3BA12,000000
68,66,"DE BROUCKERE - PEAGE",,3,,36578C,FFFFFF
73,69,"SCHAERBEEK GARE - JULES BORDET",,3,,E87D0D,FFFFFF
56,71,"DE BROUCKERE - DELTA",,3,,338C26,FFFFFF
57,72,"ULB - ADEPS",,3,,FF9EC2,000000
36,75,"CAMPUS CERIA - BON AIR",,3,,F7E017,000000
45,75,"CERIA - BON AIR",,3,,F7E017,000000
58,76,"KRAAINEM - OPPEM",,3,,F7E017,000000
59,77,"KRAAINEM - HIPPODROME",,3,,338C26,FFFFFF
84,78,"HUMANITE - GARE DU MIDI",,3,,B085B3,FFFFFF
71,79,"KRAAINEM - SCHUMAN",,3,,36578C,FFFFFF
60,80,"PORTE DE NAMUR - HAREN",,3,,338C26,FFFFFF
18,81,"MARIUS RENARD - MONTGOMERY",,0,,338C26,FFFFFF
11,82,"BERCHEM STATION - DROGENBOS CHATEAU",,0,,9EBFE3,000000
38,83,"BERCHEM STATION - HEYSEL",,3,,B5BA05,000000
32,86,"MACHTENS - GARE CENTRALE",,3,,338C26,FFFFFF
26,87,"SIMONIS - BEEKKANT",,3,,338C26,FFFFFF
39,88,"DE BROUCKERE - UZ-VUB",,3,,991F36,FFFFFF
31,89,"WESTLAND SHOPPING - BOCKSTAEL",,3,,E87D0D,FFFFFF
20,92,"SCHAERBEEK GARE - FORT-JACO",,0,,DE3B21,FFFFFF
21,93,"STADE - LEGRAND",,0,,E87D0D,FFFFFF
61,95,"GRAND-PLACE - WIENER",,3,,36578C,FFFFFF
19,97,"LOUISE - DIEWEG",,0,,991F36,FFFFFF
37,98,"CERIA - HEROS",,3,,FC8306,FFFFFF
46,T39,"MARCELIS - BAN-EIK",,3,,DE3B21,FFFFFF
64,T39,"STOCKEL - BAN-EIK",,3,,DE3B21,FFFFFF
82,T55,"DA VINCI - ROGIER",,3,,E3BA12,000000
40,T93,"STADE - LEGRAND",,3,,E87D0D,FFFFFF
80,N04,"GARE CENTRALE - CIMETIERE DE BRUXELLES",,3,,FF00FF,FFFFFF
81,N05,"GARE CENTRALE - KRAAINEM",,3,,9978B8,FFFFFF
79,N06,"GARE CENTRALE - MUSEE DU TRAM",,3,,00C8FF,FFFFFF
62,N08,"GARE CENTRALE - WIENER",,3,,94C9FD,000000
63,N09,"GARE CENTRALE - HERRMANN-DEBROUX",,3,,FF00FF,FFFFFF
41,N10,"GARE CENTRALE - FORT-JACO",,3,,D2FF0A,000000
85,N11,"GARE CENTRALE - HOMBORCH",,3,,976A0E,FFFFFF
43,N12,"GARE CENTRALE - CARREFOUR STALLE",,3,,FC8306,FFFFFF
86,N13,"GARE CENTRALE - WESTLAND SHOPPING",,3,,C30C3E,FFFFFF
44,N16,"GARE CENTRALE - BERCHEM STATION",,3,,0A3C0A,FFFFFF
42,N18,"GARE CENTRALE - HEYSEL",,3,,64D214,FFFFFF
"""

TRANSLATIONS_CSV_FILE = """\
trans_id,translation,lang
STIB,STIB,fr
STIB,MIVB,nl
http://www.stib-mivb.be,http://www.stib-mivb.be/index.htm?l=fr,fr
http://www.stib-mivb.be,http://www.stib-mivb.be/index.htm?l=nl,nl
ABBAYE,Abbaye,fr
ABBAYE,Abdij,nl
ACACIAS,Acacias,fr
ACACIAS,Acacia,nl
ADEPS,ADEPS,fr
ADEPS,ADEPS,nl
AERODROME,Aérodrome,fr
AERODROME,Vliegveld,nl
ALBERT,Albert,fr
ALBERT,Albert,nl
ALBERT I,Albert I,fr
ALBERT I,Albert I,nl
ALCYONS,Alcyons,fr
ALCYONS,Alcyons,nl
ALMA,Alma,fr
ALMA,Alma,nl
ALPHONSE XIII,Alphonse XIII,fr
ALPHONSE XIII,Alphonse XIII,nl
ALTITUDE CENT,Altitude Cent,fr
ALTITUDE CENT,Hoogte Honderd,nl
AMBIORIX,Ambiorix,fr
AMBIORIX,Ambiorix,nl
AMETHYSTE,Améthyste,fr
AMETHYSTE,Amethist,nl
AMITIE,Amitié,fr
AMITIE,Vriendschap,nl
ANATOLE FRANCE,Anatole France,fr
ANATOLE FRANCE,Anatole France,nl
ANCIENNE BARRIERE,Ancienne Barrière,fr
ANCIENNE BARRIERE,Oude Afspanning,nl
ANDROMEDE,Andromède,fr
ANDROMEDE,Andromeda,nl
ANNECY,Annecy,fr
ANNECY,Annecy,nl
ANNEESSENS,Anneessens,fr
ANNEESSENS,Anneessens,nl
ANTOON VAN OSS,Antoon Van Oss,fr
ANTOON VAN OSS,Antoon Van Oss,nl
AQUIRIS,Aquiris,fr
AQUIRIS,Aquiris,nl
ARAUCARIA,Araucaria,fr
ARAUCARIA,Araucaria,nl
ARBRE BALLON,Arbre Ballon,fr
ARBRE BALLON,Dikke Beuk,nl
ARBRE UNIQUE,Arbre Unique,fr
ARBRE UNIQUE,Eenboom,nl
ARCADES,Arcades,fr
ARCADES,Arcaden,nl
ARCHIDUCS,Archiducs,fr
ARCHIDUCS,Aartshertogen,nl
ARENBERG,Arenberg,fr
ARENBERG,Arenberg,nl
ARIANE,Ariane,fr
ARIANE,Ariane,nl
ARISTIDE BRIAND,Aristide Briand,fr
ARISTIDE BRIAND,Aristide Briand,nl
ARSENAL,Arsenal,fr
ARSENAL,Arsenaal,nl
ARTEMIS,Artémis,fr
ARTEMIS,Artémis,nl
ARTISTES,Artistes,fr
ARTISTES,Kunstenaars,nl
ARTS ET METIERS,Arts et Métiers,fr
ARTS ET METIERS,Arts et Métiers,nl
ARTS-LOI,Arts-Loi,fr
ARTS-LOI,Kunst-Wet,nl
AUDERGHEM-FORET,Auderghem-Forêt,fr
AUDERGHEM-FORET,Oudergem-Woud,nl
AUDERGHEM-SHOP.,Auderghem-Shopping,fr
AUDERGHEM-SHOP.,Oudergem-Shopping,nl
AUDITOIRES-UCL,Auditoires-UCL,fr
AUDITOIRES-UCL,Auditoires-UCL,nl
AULNE,Aulne,fr
AULNE,Elzeboom,nl
AUMALE,Aumale,fr
AUMALE,Aumale,nl
AUTRIQUE,Autrique,fr
AUTRIQUE,Autrique,nl
AVANT-PORT,Avant-Port,fr
AVANT-PORT,Voorhaven,nl
AVENUE DU PORT,Avenue du Port,fr
AVENUE DU PORT,Havenlaan,nl
AVENUE DU ROI,Avenue du Roi,fr
AVENUE DU ROI,Koningslaan,nl
AVIATION,Aviation,fr
AVIATION,Luchtvaart,nl
AZALEES,Azalées,fr
AZALEES,Azalea,nl
AZUR,Azur,fr
AZUR,Azuur,nl
BAILLI,Bailli,fr
BAILLI,Baljuw,nl
BALE,Bâle,fr
BALE,Bazel,nl
BAN-EIK,Ban-Eik,fr
BAN-EIK,Ban-Eik,nl
BARA,Bara,fr
BARA,Bara,nl
BARON DE CASTRO,Baron de Castro,fr
BARON DE CASTRO,Baron de Castro,nl
BARRIERE,Barrière,fr
BARRIERE,Bareel,nl
BASCULE,Bascule,fr
BASCULE,Bascule,nl
BASILIX,Basilix,fr
BASILIX,Basilix,nl
BASTOGNE,Bastogne,fr
BASTOGNE,Bastenaken,nl
BAYENS,Bayens,fr
BAYENS,Bayens,nl
BEAULIEU,Beaulieu,fr
BEAULIEU,Beaulieu,nl
BEAUTE,Beauté,fr
BEAUTE,Schoonheid,nl
BEECKMANS,Beeckmans,fr
BEECKMANS,Beeckmans,nl
BEEKKANT,Beekkant,fr
BEEKKANT,Beekkant,nl
BEGUINAGE,Béguinage,fr
BEGUINAGE,Begijnhof,nl
BEKA,Beka,fr
BEKA,Beka,nl
BEL-AIR,Bel-Air,fr
BEL-AIR,Schone Lucht,nl
BELGICA,Belgica,fr
BELGICA,Belgica,nl
BEMPT,Bempt,fr
BEMPT,Bempt,nl
BENES,Bénès,fr
BENES,Bénès,nl
BENS,Bens,fr
BENS,Bens,nl
BERCHEM STATION,Berchem Station,fr
BERCHEM STATION,Berchem Station,nl
BERCHEM-SHOPPING,Berchem-Shopping,fr
BERCHEM-SHOPPING,Berchem-Shopping,nl
BERENSHEIDE,Berensheide,fr
BERENSHEIDE,Berensheide,nl
BERGOJE,Bergoje,fr
BERGOJE,Bergoje,nl
BERKENDAEL,Berkendael,fr
BERKENDAEL,Berkendaal,nl
BERTHELOT,Berthelot,fr
BERTHELOT,Berthelot,nl
BERVOETS,Bervoets,fr
BERVOETS,Bervoets,nl
BESME,Besme,fr
BESME,Besme,nl
BETHLEEM,Bethléem,fr
BETHLEEM,Bethlehem,nl
BEYSEGHEM,Beyseghem,fr
BEYSEGHEM,Beizegem,nl
BIARRITZ,Biarritz,fr
BIARRITZ,Biarritz,nl
BIBLIOTHEQUE,Bibliothèque,fr
BIBLIOTHEQUE,Bibliotheek,nl
BICHON,Bichon,fr
BICHON,Bichon,nl
BICOQUE,Bicoque,fr
BICOQUE,Bicoque,nl
BIEBUYCK,Biebuyck,fr
BIEBUYCK,Biebuyck,nl
BIEN-FAIRE,Bien-Faire,fr
BIEN-FAIRE,Bien-Faire,nl
BIENFAITEURS,Bienfaiteurs,fr
BIENFAITEURS,Weldoeners,nl
BIGARREAUX,Bigarreaux,fr
BIGARREAUX,Vleeskersen,nl
BIPLAN,Biplan,fr
BIPLAN,Tweedekker,nl
BIZET,Bizet,fr
BIZET,Bizet,nl
BLOKKEN,Blokken,fr
BLOKKEN,Blokken,nl
BLYCKAERTS,Blyckaerts,fr
BLYCKAERTS,Blyckaerts,nl
BOCKSTAEL,Bockstael,fr
BOCKSTAEL,Bockstael,nl
BOCKSTAEL GARE,Bockstael Gare,fr
BOCKSTAEL GARE,Bockstael Station,nl
BODEGHEM,Bodeghem,fr
BODEGHEM,Bodegem,nl
BOETENDAEL,Boetendael,fr
BOETENDAEL,Boetendael,nl
BOILEAU,Boileau,fr
BOILEAU,Boileau,nl
BOIS DES ILES,Bois des Îles,fr
BOIS DES ILES,Eilandenhout,nl
BOITSFORT GARE,Boitsfort Gare,fr
BOITSFORT GARE,Bosvoorde Station,nl
BOLLINCKX,Bollinckx,fr
BOLLINCKX,Bollinckx,nl
BON AIR,Bon Air,fr
BON AIR,Goede Lucht,nl
BONAVENTURE,Bonaventure,fr
BONAVENTURE,Bonaventure,nl
BOONDAEL GARE,Boondael Gare,fr
BOONDAEL GARE,Boondaal Station,nl
BORDET STATION,Bordet Station,fr
BORDET STATION,Bordet Station,nl
BORNE,Borne,fr
BORNE,Paal,nl
BOSSAERT-BASILIQ.,Bossaert-Basilique,fr
BOSSAERT-BASILIQ.,Bossaert-Basiliek,nl
BOSSUET,Bossuet,fr
BOSSUET,Bossuet,nl
BOTANIQUE,Botanique,fr
BOTANIQUE,Kruidtuin,nl
BOULEAUX,Bouleaux,fr
BOULEAUX,Berken,nl
BOURDON,Bourdon,fr
BOURDON,Horzel,nl
BOURGET,Bourget,fr
BOURGET,Bourget,nl
BOURSE,Bourse,fr
BOURSE,Beurs,nl
BOZAR,Bozar,fr
BOZAR,Bozar,nl
BRABANCONNE,Brabançonne,fr
BRABANCONNE,Brabançonne,nl
BRAEMT,Braemt,fr
BRAEMT,Braemt,nl
BRAVES,Braves,fr
BRAVES,Dapperen,nl
BREESCH,Breesch,fr
BREESCH,Breesch,nl
BRESIL,Brésil,fr
BRESIL,Brazilië,nl
BREYDEL,Breydel,fr
BREYDEL,Breydel,nl
BRILLANT,Brillant,fr
BRILLANT,Briljant,nl
BROEK,Broek,fr
BROEK,Broek,nl
BROEREN,Broeren,fr
BROEREN,Broeren,nl
BROUSTIN,Broustin,fr
BROUSTIN,Broustin,nl
BRUNARD,Brunard,fr
BRUNARD,Brunard,nl
BRUSSELS AIRPORT,Brussels Airport,fr
BRUSSELS AIRPORT,Brussels Airport,nl
BRUSSELSESTEENWEG,Brusselsesteenweg,fr
BRUSSELSESTEENWEG,Brusselsesteenweg,nl
BRUXELLOIS,Bruxellois,fr
BRUXELLOIS,Brusselaars,nl
BUANDERIE,Buanderie,fr
BUANDERIE,Washuis,nl
BUEDTS,Buedts,fr
BUEDTS,Buedts,nl
BUISSONNETS,Buissonnets,fr
BUISSONNETS,Braambosjes,nl
BUYL,Buyl,fr
BUYL,Buyl,nl
CABRIS,Cabris,fr
CABRIS,Geitjes,nl
CALYPSO 2000,Calypso 2000,fr
CALYPSO 2000,Calypso 2000,nl
CAMBRE-ETOILE,Cambre-Étoile,fr
CAMBRE-ETOILE,Ter Kameren-Ster,nl
CAMPUS CERIA,Campus CERIA,fr
CAMPUS CERIA,Campus COOVI,nl
CANDRIES,Candries,fr
CANDRIES,Candries,nl
CAPRICORNE,Capricorne,fr
CAPRICORNE,Steenbok,nl
CARENE,Carène,fr
CARENE,Carina,nl
CARLI,Carli,fr
CARLI,Carli,nl
CARREFOUR STALLE,Carrefour Stalle,fr
CARREFOUR STALLE,Kruispunt Stalle,nl
CAVELL,Cavell,fr
CAVELL,Cavell,nl
CENTENAIRE,Centenaire,fr
CENTENAIRE,Eeuwfeest,nl
CERES,Ceres,fr
CERES,Ceres,nl
CERIA,CERIA,fr
CERIA,COOVI,nl
CERISAIE,Cerisaie,fr
CERISAIE,Kerseboomgaard,nl
CESAR DE PAEPE,César De Paepe,fr
CESAR DE PAEPE,César De Paepe,nl
CHANT D'OISEAU,Chant d'Oiseau,fr
CHANT D'OISEAU,Vogelzang,nl
CHAPELLE,Chapelle,fr
CHAPELLE,Kapellekerk,nl
CHARMILLE,Charmille,fr
CHARMILLE,Haagbeuken,nl
CHARROI,Charroi,fr
CHARROI,Gerij,nl
CHASSEURS ARDEN.,Chasseurs Ardennais,fr
CHASSEURS ARDEN.,Ardense Jagers,nl
CHATAIGNES,Châtaignes,fr
CHATAIGNES,Kastanjes,nl
CHAUMONTEL,Chaumontel,fr
CHAUMONTEL,Chaumontel,nl
CHAZAL,Chazal,fr
CHAZAL,Chazal,nl
CHEMIN DE FER,Chemin de Fer,fr
CHEMIN DE FER,Spoorweg,nl
CHEMIN VERT,Chemin Vert,fr
CHEMIN VERT,Groenweg,nl
CHENAIE,Chênaie,fr
CHENAIE,Eikenbos,nl
CHEVALERIE,Chevalerie,fr
CHEVALERIE,Ridderschap,nl
CHIEN VERT,Chien Vert,fr
CHIEN VERT,Groene Hond,nl
CHIREC,Chirec,fr
CHIREC,Chirec,nl
CHOPIN,Chopin,fr
CHOPIN,Chopin,nl
CHURCHILL,Churchill,fr
CHURCHILL,Churchill,nl
CICERON,Cicéron,fr
CICERON,Cicero,nl
CIM. D'IXELLES,Cimetière d'Ixelles,fr
CIM. D'IXELLES,Begraafplaats van Elsene,nl
CIM. DE BRUXELLES,Cimetière de Bruxelles,fr
CIM. DE BRUXELLES,Begraafplaats van Brussel,nl
CIM. DE JETTE,Cimetière de Jette,fr
CIM. DE JETTE,Kerkhof van Jette,nl
CIM. DE MOLENBEEK,Cimetière de Molenbeek,fr
CIM. DE MOLENBEEK,Begraafplaats van Molenbeek,nl
CIMETIERES,Cimetières,fr
CIMETIERES,Begraafplaatsen,nl
CITE MODELE 4,Cité Modèle 4,fr
CITE MODELE 4,Modelwijk 4,nl
CLAESSENS,Claessens,fr
CLAESSENS,Claessens,nl
CLAYS,Clays,fr
CLAYS,Clays,nl
CLEMENCEAU,Clemenceau,fr
CLEMENCEAU,Clemenceau,nl
CLESSE,Clesse,fr
CLESSE,Clesse,nl
CLINIQUES-UCL,Cliniques-UCL,fr
CLINIQUES-UCL,Cliniques-UCL,nl
CLOVIS,Clovis,fr
CLOVIS,Clovis,nl
COCCINELLES,Coccinelles,fr
COCCINELLES,Lieveheersbeestjes,nl
COGHEN,Coghen,fr
COGHEN,Coghen,nl
COLLEGE S.-COEUR,Collège Sacré-Cœur,fr
COLLEGE S.-COEUR,Heilig Hartcollege,nl
COLLEGE ST-PIERRE,Collège Saint-Pierre,fr
COLLEGE ST-PIERRE,Sint-Pieterscollege,nl
COLOMBOPHILES,Colombophiles,fr
COLOMBOPHILES,Duivenmelkers,nl
COLONEL BOURG,Colonel Bourg,fr
COLONEL BOURG,Kolonel Bourg,nl
COMBAZ,Combaz,fr
COMBAZ,Combaz,nl
COMHAIRE,Comhaire,fr
COMHAIRE,Comhaire,nl
COMTE DE FLANDRE,Comte de Flandre,fr
COMTE DE FLANDRE,Graaf van Vlaanderen,nl
CONDOR,Condor,fr
CONDOR,Condor,nl
CONGRES,Congrès,fr
CONGRES,Congres,nl
CONSCIENCE,Conscience,fr
CONSCIENCE,Conscience,nl
CONSEIL,Conseil,fr
CONSEIL,Raad,nl
CORTENBACH,Cortenbach,fr
CORTENBACH,Kortenbach,nl
COTEAUX,Coteaux,fr
COTEAUX,Wijnheuvelen,nl
CPAS GANSHOREN,CPAS Ganshoren,fr
CPAS GANSHOREN,OCMW Ganshoren,nl
CRAINHEM,Crainhem,fr
CRAINHEM,Kraainem,nl
CREMATORIUM,Crematorium,fr
CREMATORIUM,Crematorium,nl
CROCQ,Crocq,fr
CROCQ,Crocq,nl
CROSSING,Crossing,fr
CROSSING,Crossing,nl
CUREGHEM,Cureghem,fr
CUREGHEM,Kuregem,nl
DA VINCI,Da Vinci,fr
DA VINCI,Da Vinci,nl
DAILLY,Dailly,fr
DAILLY,Dailly,nl
DANSAERT,Dansaert,fr
DANSAERT,Dansaert,nl
DARWIN,Darwin,fr
DARWIN,Darwin,nl
DAUTZENBERG,Dautzenberg,fr
DAUTZENBERG,Dautzenberg,nl
DE BEJAR,De Bejar,fr
DE BEJAR,De Bejar,nl
DE BERLAIMONT,de Berlaimont,fr
DE BERLAIMONT,de Berlaimont,nl
DE BROUCKERE,De Brouckère,fr
DE BROUCKERE,De Brouckère,nl
DE BURBURE,de Burbure,fr
DE BURBURE,de Burbure,nl
DE HEYN,De Heyn,fr
DE HEYN,De Heyn,nl
DE LINDE,De Linde,fr
DE LINDE,De Linde,nl
DE LOMBAERDE,de Lombaerde,fr
DE LOMBAERDE,de Lombaerde,nl
DE VILLALOBAR,de Villalobar,fr
DE VILLALOBAR,de Villalobar,nl
DE WAND,De Wand,fr
DE WAND,De Wand,nl
DE WANSIJN,De Wansijn,fr
DE WANSIJN,De Wansijn,nl
DECROLY,Decroly,fr
DECROLY,Decroly,nl
DEFACQZ,Defacqz,fr
DEFACQZ,Defacqz,nl
DEGROOFF,Degrooff,fr
DEGROOFF,Degrooff,nl
DELACROIX,Delacroix,fr
DELACROIX,Delacroix,nl
DELLEUR,Delleur,fr
DELLEUR,Delleur,nl
DELPORTE,Delporte,fr
DELPORTE,Delporte,nl
DELTA,Delta,fr
DELTA,Delta,nl
DEMEY,Demey,fr
DEMEY,Demey,nl
DEMINEURS,Démineurs,fr
DEMINEURS,Ontmijners,nl
DEMOLDER,Demolder,fr
DEMOLDER,Demolder,nl
DEMUNTER,Demunter,fr
DEMUNTER,Demunter,nl
DEPORTES,Déportés,fr
DEPORTES,Weggevoerden,nl
DEPOT,Dépôt,fr
DEPOT,Stelplaats,nl
DESTOUVELLES,Destouvelles,fr
DESTOUVELLES,Destouvelles,nl
DEUTSCHE SCHULE,Deutsche Schule,fr
DEUTSCHE SCHULE,Deutsche Schule,nl
DEUX CHAUSSEES,Deux Chaussées,fr
DEUX CHAUSSEES,Tweesteenwegen,nl
DEUX GARES,Deux Gares,fr
DEUX GARES,Twee Stations,nl
DGHR DOMAINE MIL.,DGHR Domaine Militaire,fr
DGHR DOMAINE MIL.,DGHR Militair Domein,nl
DIABLOTINS,Diablotins,fr
DIABLOTINS,Duiveltjes,nl
DIABOLO,Diabolo,fr
DIABOLO,Diabolo,nl
DIAMANT,Diamant,fr
DIAMANT,Diamant,nl
DIEGEMSTRAAT,Diegemstraat,fr
DIEGEMSTRAAT,Diegemstraat,nl
DIELEGHEM,Dieleghem,fr
DIELEGHEM,Dielegem,nl
DIEUDONNE LEFEVRE,Dieudonné Lefèvre,fr
DIEUDONNE LEFEVRE,Dieudonné Lefèvre,nl
DIEWEG,Dieweg,fr
DIEWEG,Dieweg,nl
DIGUE DU CANAL,Digue du Canal,fr
DIGUE DU CANAL,Vaartdijk,nl
DIRECTOIRE,Directoire,fr
DIRECTOIRE,Directoire,nl
DIVIN SAUVEUR,Divin Sauveur,fr
DIVIN SAUVEUR,Goddelijke Zaligmaker,nl
DOCKS BRUXSEL,Docks Bruxsel,fr
DOCKS BRUXSEL,Docks Bruxsel,nl
DOMAINE,Domaine,fr
DOMAINE,Domein,nl
DON BOSCO,Don Bosco,fr
DON BOSCO,Don Bosco,nl
DORENT,Dorent,fr
DORENT,Dorent,nl
DOUVRES,Douvres,fr
DOUVRES,Dover,nl
DREVE DE NIVELLES,Drève de Nivelles,fr
DREVE DE NIVELLES,Nijvelsedreef,nl
DREVE DES BRULES,Drève des Brûlés,fr
DREVE DES BRULES,Verbrandendreef,nl
DRIE FONTEINEN,Drie Fonteinen,fr
DRIE FONTEINEN,Drie Fonteinen,nl
DRIES,Dries,fr
DRIES,Dries,nl
DROGENBOS CHATEAU,Drogenbos Château,fr
DROGENBOS CHATEAU,Drogenbos Kasteel,nl
DROGENBOS-SHOP.,Drogenbos-Shopping,fr
DROGENBOS-SHOP.,Drogenbos-Shopping,nl
DROSSART,Drossart,fr
DROSSART,Drossaard,nl
DUBOIS,Dubois,fr
DUBOIS,Dubois,nl
DUCHESSE BRABANT,Duchesse de Brabant,fr
DUCHESSE BRABANT,Hertogin van Brabant,nl
DUDEN,Duden,fr
DUDEN,Duden,nl
DUNANT,Dunant,fr
DUNANT,Dunant,nl
DUNETTE,Dunette,fr
DUNETTE,Dunette,nl
DUYSBURGH,Duysburgh,fr
DUYSBURGH,Duysburgh,nl
EDDY MERCKX,Eddy Merckx,fr
EDDY MERCKX,Eddy Merckx,nl
EENENS,Eenens,fr
EENENS,Eenens,nl
EGGERGAT,Eggergat,fr
EGGERGAT,Eggergat,nl
EGIDE VAN OPHEM,Egide Van Ophem,fr
EGIDE VAN OPHEM,Egide Van Ophem,nl
EGLANTIERS,Églantiers,fr
EGLANTIERS,Wilderozen,nl
EGLISE ST-ANTOINE,Église Saint-Antoine,fr
EGLISE ST-ANTOINE,Sint-Antoonkerk,nl
EGLISE ST-JULIEN,Église Saint-Julien,fr
EGLISE ST-JULIEN,Sint-Juliaanskerk,nl
EGLISE ST-SERVAIS,Église Saint-Servais,fr
EGLISE ST-SERVAIS,Sint-Servaaskerk,nl
EGLISE WEZEMBEEK,Église Wezembeek,fr
EGLISE WEZEMBEEK,Kerk Wezembeek,nl
ELBERS,Elbers,fr
ELBERS,Elbers,nl
ELEPHANT,Éléphant,fr
ELEPHANT,Olifant,nl
ELISABETH,Elisabeth,fr
ELISABETH,Elisabeth,nl
ELOY,Eloy,fr
ELOY,Eloy,nl
EMPAIN,Empain,fr
EMPAIN,Empain,nl
ENGELAND,Engeland,fr
ENGELAND,Engeland,nl
ENNEPETAL,Ennepetal,fr
ENNEPETAL,Ennepetal,nl
ENTREPOT,Entrepôt,fr
ENTREPOT,Stapelhuis,nl
EQUIPAGES,Équipages,fr
EQUIPAGES,Jachtstoet,nl
ERASME,Erasme,fr
ERASME,Erasmus,nl
ERNEST LAUDE,Ernest Laude,fr
ERNEST LAUDE,Ernest Laude,nl
ERNEST SALU,Ernest Salu,fr
ERNEST SALU,Ernest Salu,nl
ESCAUT,Escaut,fr
ESCAUT,Schelde,nl
ESCRIME,Escrime,fr
ESCRIME,Schermkunst,nl
ESPLANADE,Esplanade,fr
ESPLANADE,Esplanade,nl
ETANGS,Étangs,fr
ETANGS,Vijvers,nl
ETANGS BOITSFORT,Étangs de Boitsfort,fr
ETANGS BOITSFORT,Vijvers van Bosvoorde,nl
ETANGS D'IXELLES,Étangs d'Ixelles,fr
ETANGS D'IXELLES,Vijvers van Elsene,nl
ETANGS NOIRS,Étangs Noirs,fr
ETANGS NOIRS,Zwarte Vijvers,nl
ETTERBEEK GARE,Etterbeek Gare,fr
ETTERBEEK GARE,Etterbeek Station,nl
EUGENE TOUSSAINT,Eugène Toussaint,fr
EUGENE TOUSSAINT,Eugène Toussaint,nl
EUROCONTROL,Eurocontrol,fr
EUROCONTROL,Eurocontrol,nl
EVERE GARE,Evere Gare,fr
EVERE GARE,Evere Station,nl
EVERE SHOPPING,Evere Shopping,fr
EVERE SHOPPING,Evere Shopping,nl
EXPOSITION,Exposition,fr
EXPOSITION,Tentoonstelling,nl
FAIDER,Faider,fr
FAIDER,Faider,nl
FAUCONNERIE,Fauconnerie,fr
FAUCONNERIE,Valkerij,nl
FERME NOS PILIFS,Ferme Nos Pilifs,fr
FERME NOS PILIFS,Ferme Nos Pilifs,nl
FERNAND COCQ,Fernand Cocq,fr
FERNAND COCQ,Fernand Cocq,nl
FERNAND LEGER,Fernand Léger,fr
FERNAND LEGER,Fernand Léger,nl
FETIS,Fétis,fr
FETIS,Fétis,nl
FEVRIER,Février,fr
FEVRIER,Februari,nl
FIRMIN LECHARLIER,Firmin Lecharlier,fr
FIRMIN LECHARLIER,Firmin Lecharlier,nl
FLAGEY,Flagey,fr
FLAGEY,Flagey,nl
FLORIDE,Floride,fr
FLORIDE,Florida,nl
FONSON,Fonson,fr
FONSON,Fonson,nl
FOREST (BERVOETS),Forest Centre (Bervoets),fr
FOREST (BERVOETS),Vorst Centrum (Bervoets),nl
FOREST CENTRE,Forest Centre,fr
FOREST CENTRE,Vorst Centrum,nl
FOREST NATIONAL,Forest National,fr
FOREST NATIONAL,Vorst Nationaal,nl
FOREST-EST,Forest-Est,fr
FOREST-EST,Vorst-Oost,nl
FORESTERIE,Foresterie,fr
FORESTERIE,Vorsterie,nl
FORESTOISE,Forestoise,fr
FORESTOISE,Forestoise,nl
FORT-JACO,Fort-Jaco,fr
FORT-JACO,Fort-Jaco,nl
FOYER JETTOIS,Foyer Jettois,fr
FOYER JETTOIS,Jetse Haard,nl
FOYER SCHAERBEEK.,Foyer Schaerbeekois,fr
FOYER SCHAERBEEK.,Schaarbeekse Haard,nl
FRAITEUR,Fraiteur,fr
FRAITEUR,Fraiteur,nl
FRANS COURTENS,Frans Courtens,fr
FRANS COURTENS,Frans Courtens,nl
FRANS HALS,Frans Hals,fr
FRANS HALS,Frans Hals,nl
FROISSART,Froissart,fr
FROISSART,Froissart,nl
FRUITS,Fruits,fr
FRUITS,Fruit,nl
FUSEE,Fusée,fr
FUSEE,Raket,nl
FUSS,Fuss,fr
FUSS,Fuss,nl
FUTAIE,Futaie,fr
FUTAIE,Futaie,nl
G-BIJGAARDEN STAT,Groot-Bijgaarden Station,fr
G-BIJGAARDEN STAT,Groot-Bijgaarden Station,nl
GANSHOREN-SPORT,Ganshoren-Sport,fr
GANSHOREN-SPORT,Ganshoren-Sport,nl
GARDON,Gardon,fr
GARDON,Voorn,nl
GARE CENTRALE,Gare Centrale,fr
GARE CENTRALE,Centraal Station,nl
GARE DE L'OUEST,Gare de l'Ouest,fr
GARE DE L'OUEST,Weststation,nl
GARE DE LINKEBEEK,Gare de Linkebeek,fr
GARE DE LINKEBEEK,Station Linkebeek,nl
GARE DE SAINT-JOB,Gare de Saint-Job,fr
GARE DE SAINT-JOB,Station Sint-Job,nl
GARE DU MIDI,Gare du Midi,fr
GARE DU MIDI,Zuidstation,nl
GARE DU NORD,Gare du Nord,fr
GARE DU NORD,Noordstation,nl
GAULOIS,Gaulois,fr
GAULOIS,Galliërs,nl
GAZELLE,Gazelle,fr
GAZELLE,Gazelle,nl
GEEFS,Geefs,fr
GEEFS,Geefs,nl
GENDARMES,Gendarmes,fr
GENDARMES,Gendarmen,nl
GENEVE,Genève,fr
GENEVE,Genève,nl
GENOT,Genot,fr
GENOT,Genot,nl
GEO BERNIER,Géo Bernier,fr
GEO BERNIER,Géo Bernier,nl
GEORGES BRUGMANN,Georges Brugmann,fr
GEORGES BRUGMANN,Georges Brugmann,nl
GEORGES HENRI,Georges Henri,fr
GEORGES HENRI,Georges Henri,nl
GERGEL,Gergel,fr
GERGEL,Gergel,nl
GERMOIR,Germoir,fr
GERMOIR,Mouterij,nl
GERSIS,Gersis,fr
GERSIS,Gersis,nl
GILLON,Gillon,fr
GILLON,Gillon,nl
GILSON,Gilson,fr
GILSON,Gilson,nl
GJ MARTIN,GJ Martin,fr
GJ MARTIN,GJ Martin,nl
GLIBERT,Glibert,fr
GLIBERT,Glibert,nl
GLOBE,Globe,fr
GLOBE,Globe,nl
GOFFIN,Goffin,fr
GOFFIN,Goffin,nl
GOSSART,Gossart,fr
GOSSART,Gossart,nl
GRAND SABLON,Grand Sablon,fr
GRAND SABLON,Grote Zavel,nl
GRAND'ROUTE,Grand'Route,fr
GRAND'ROUTE,Grote Baan,nl
GRAND-PLACE,Grand-Place,fr
GRAND-PLACE,Grote Markt,nl
GRIBAUMONT,Gribaumont,fr
GRIBAUMONT,Gribaumont,nl
GRIOTTES,Griottes,fr
GRIOTTES,Noordkrieken,nl
GROELSTVELD,Groelstveld,fr
GROELSTVELD,Groelstveld,nl
GROENINGHE,Groeninghe,fr
GROENINGHE,Groeninghe,nl
GROOT-BIJGAARDEN,Groot-Bijgaarden,fr
GROOT-BIJGAARDEN,Groot-Bijgaarden,nl
GUEUX,Gueux,fr
GUEUX,Geuzen,nl
GUI,Gui,fr
GUI,Marentak,nl
GUILL. DE GREEF,Guillaume De Greef,fr
GUILL. DE GREEF,Guillaume De Greef,nl
GUILLAUME,Guillaume,fr
GUILLAUME,Guillaume,nl
GUILLAUME TELL,Guillaume Tell,fr
GUILLAUME TELL,Willem Tell,nl
GULLEDELLE,Gulledelle,fr
GULLEDELLE,Gulledelle,nl
GUTENBERG,Gutenberg,fr
GUTENBERG,Gutenberg,nl
HANKAR,Hankar,fr
HANKAR,Hankar,nl
HANNETONS,Hannetons,fr
HANNETONS,Meikevers,nl
HANSSENSPARK,Hanssenspark,fr
HANSSENSPARK,Hanssenspark,nl
HAREN-ATELIER,Haren-Atelier,fr
HAREN-ATELIER,Haren-Werkplaats,nl
HAREN-STIB,Haren-STIB,fr
HAREN-STIB,Haren-MIVB,nl
HAREN-SUD,Haren-Sud,fr
HAREN-SUD,Haren-Zuid,nl
HEEMBEEK,Heembeek,fr
HEEMBEEK,Heembeek,nl
HEILIGENBORRE,Heiligenborre,fr
HEILIGENBORRE,Heiligenborre,nl
HELDENPLEIN,Heldenplein,fr
HELDENPLEIN,Heldenplein,nl
HELIOTROPES,Héliotropes,fr
HELIOTROPES,Heliotropen,nl
HELLEVELT,Hellevelt,fr
HELLEVELT,Hellevelt,nl
HELMET,Helmet,fr
HELMET,Helmet,nl
HENRI REY,Henri Rey,fr
HENRI REY,Henri Rey,nl
HERMAN,Herman,fr
HERMAN,Herman,nl
HERMES,Hermes,fr
HERMES,Hermes,nl
HERNALSTEEN,Hernalsteen,fr
HERNALSTEEN,Hernalsteen,nl
HEROS,Héros,fr
HEROS,Helden,nl
HERRMANN-DEBROUX,Herrmann-Debroux,fr
HERRMANN-DEBROUX,Herrmann-Debroux,nl
HET VEROOST,Het Veroost,fr
HET VEROOST,Het Veroost,nl
HEYDENBERG,Heydenberg,fr
HEYDENBERG,Heydenberg,nl
HEYSEL,Heysel,fr
HEYSEL,Heizel,nl
HIPPOD. BOITSFORT,Hippodrome de Boitsfort,fr
HIPPOD. BOITSFORT,Renbaan van Bosvoorde,nl
HIPPODROME,Hippodrome,fr
HIPPODROME,Hippodroom,nl
HOEDEMAEKERS,Hoedemaekers,fr
HOEDEMAEKERS,Hoedemaekers,nl
HOF TEN BERG,Hof ten Berg,fr
HOF TEN BERG,Hof ten Berg,nl
HOF TER MUSSCHEN,Hof ter Musschen,fr
HOF TER MUSSCHEN,Hof ter Musschen,nl
HOMBORCH,Homborch,fr
HOMBORCH,Homborch,nl
HOOGBOSCH,Hoogbosch,fr
HOOGBOSCH,Hoogbosch,nl
HOOGVELD,Hoogveld,fr
HOOGVELD,Hoogveld,nl
HOP. ETT.-IXELLES,Hôpital Etterbeek-Ixelles,fr
HOP. ETT.-IXELLES,Ziekenhuis Etterbeek-Elsene,nl
HOP. MILITAIRE,Hôpital Militaire,fr
HOP. MILITAIRE,Militair Hospitaal,nl
HOP. PAUL BRIEN,Hôpital Paul Brien,fr
HOP. PAUL BRIEN,Paul Brien-ziekenhuis,nl
HOP. SAINT-PIERRE,Hôpital Saint-Pierre,fr
HOP. SAINT-PIERRE,Sint-Pieters-ziekenhuis,nl
HOP.STE-ELISABETH,Hôpital Sainte-Élisabeth,fr
HOP.STE-ELISABETH,Sint-Elizabeth-ziekenhuis,nl
HOPITAL BRACOPS,Hôpital Joseph Bracops,fr
HOPITAL BRACOPS,Joseph Bracops-ziekenhuis,nl
HOPITAL BRUGMANN,Hôpital Brugmann,fr
HOPITAL BRUGMANN,Brugmann-ziekenhuis,nl
HOPITAL ENFANTS,Hôpital des Enfants,fr
HOPITAL ENFANTS,Kinderziekenhuis,nl
HORTA,Horta,fr
HORTA,Horta,nl
HOSPICES,Hospices,fr
HOSPICES,Godshuizen,nl
HOTEL DES MONNAIES,Hôtel des Monnaies,fr
HOTEL DES MONNAIES,Munthof,nl
HOUBA-BRUGMANN,Houba-Brugmann,fr
HOUBA-BRUGMANN,Houba-Brugmann,nl
HOUWAERT,Houwaert,fr
HOUWAERT,Houwaert,nl
HOUZEAU,Houzeau,fr
HOUZEAU,Houzeau,nl
HUART-HAMOIR,Huart-Hamoir,fr
HUART-HAMOIR,Huart-Hamoir,nl
HUIT HEURES,Huit Heures,fr
HUIT HEURES,Acht Uren,nl
HUMANITE,Humanité,fr
HUMANITE,Humaniteit,nl
HUNDERENVELD,Hunderenveld,fr
HUNDERENVELD,Hunderenveld,nl
HYMANS,Hymans,fr
HYMANS,Hymans,nl
ICHEC,ICHEC,fr
ICHEC,ICHEC,nl
IDALIE,Idalie,fr
IDALIE,Idalie,nl
ILE SAINTE-HELENE,Île Sainte-Hélène,fr
ILE SAINTE-HELENE,Eiland Sint-Helena,nl
IMPRIMERIE,Imprimerie,fr
IMPRIMERIE,Drukkerij,nl
INTERNAT. SCHOOL,International School,fr
INTERNAT. SCHOOL,International School,nl
INTERNATIONAL,Boulevard International,fr
INTERNATIONAL,Internationalelaan,nl
INVALIDES,Invalides,fr
INVALIDES,Invaliden,nl
JACOBS FONTAINE,Jacobs Fontaine,fr
JACOBS FONTAINE,Jacobs Fontaine,nl
JACQUES BREL,Jacques Brel,fr
JACQUES BREL,Jacques Brel,nl
JAKOB SMITS,Jakob Smits,fr
JAKOB SMITS,Jakob Smits,nl
JAMBLINNE DE MEUX,de Jamblinne de Meux,fr
JAMBLINNE DE MEUX,de Jamblinne de Meux,nl
JANSON,Janson,fr
JANSON,Janson,nl
JARDIN MASSART,Jardin Massart,fr
JARDIN MASSART,Massarttuin,nl
JEANNE,Jeanne,fr
JEANNE,Johanna,nl
JESPERS,Jespers,fr
JESPERS,Jespers,nl
JETTE GARE,Jette Gare,fr
JETTE GARE,Jette Station,nl
JEU DE BALLE,Jeu de Balle,fr
JEU DE BALLE,Vossenplein,nl
JORDAEN,Jordaen,fr
JORDAEN,Jordaen,nl
JOSAPHAT,Josaphat,fr
JOSAPHAT,Josaphat,nl
JOSEPH BAECK,Joseph Baeck,fr
JOSEPH BAECK,Joseph Baeck,nl
JOSEPH.-CHARLOTTE,Joséphine-Charlotte,fr
JOSEPH.-CHARLOTTE,Joséphine-Charlotte,nl
JOURDAN,Jourdan,fr
JOURDAN,Jourdan,nl
JUBILE,Jubilé,fr
JUBILE,Jubelfeest,nl
JULES BORDET,Jules Bordet,fr
JULES BORDET,Jules Bordet,nl
JULES CESAR,Jules César,fr
JULES CESAR,Julius Cesar,nl
JULES DE TROOZ,Jules De Trooz,fr
JULES DE TROOZ,Jules De Trooz,nl
JUPITER,Jupiter,fr
JUPITER,Jupiter,nl
KAPEL RUISBROEK,Kapel Ruisbroek,fr
KAPEL RUISBROEK,Kapel Ruisbroek,nl
KAREL BOGAERD,Karel Bogaerd,fr
KAREL BOGAERD,Karel Bogaerd,nl
KARREVELD,Karreveld,fr
KARREVELD,Karreveld,nl
KASTEEL BEAULIEU,Kasteel Beaulieu,fr
KASTEEL BEAULIEU,Kasteel Beaulieu,nl
KATTENBERG,Kattenberg,fr
KATTENBERG,Kattenberg,nl
KELLE,Kelle,fr
KELLE,Kelle,nl
KENNIS,Kennis,fr
KENNIS,Kennis,nl
KERK MACHELEN,Kerk Machelen,fr
KERK MACHELEN,Kerk Machelen,nl
KERK RUISBROEK,Kerk Ruisbroek,fr
KERK RUISBROEK,Kerk Ruisbroek,nl
KERK VILVOORDE,Kerk Vilvoorde,fr
KERK VILVOORDE,Kerk Vilvoorde,nl
KEYENBEMPT,Keyenbempt,fr
KEYENBEMPT,Keyenbempt,nl
KEYM,Keym,fr
KEYM,Keym,nl
KLAKKEDELLE,Klakkedelle,fr
KLAKKEDELLE,Klakkedelle,nl
KONINGIN FABIOLA,Koningin Fabiola,fr
KONINGIN FABIOLA,Koningin Fabiola,nl
KONKEL,Konkel,fr
KONKEL,Konkel,nl
KRAAINEM,Kraainem,fr
KRAAINEM,Kraainem,nl
KRUIPWEG,Kruipweg,fr
KRUIPWEG,Kruipweg,nl
KUFFERATH,Kufferath,fr
KUFFERATH,Kufferath,nl
KURTH,Kurth,fr
KURTH,Kurth,nl
LA CHASSE,La Chasse,fr
LA CHASSE,De Jacht,nl
LA ROUE,La Roue,fr
LA ROUE,Het Rad,nl
LABEUR,Labeur,fr
LABEUR,Arbeid,nl
LAINE,Laîné,fr
LAINE,Laîné,nl
LANCASTER,Lancaster,fr
LANCASTER,Lancaster,nl
LANGEVELD,Langeveld,fr
LANGEVELD,Langeveld,nl
LATINIS,Latinis,fr
LATINIS,Latinis,nl
LE ROUX,Le Roux,fr
LE ROUX,Le Roux,nl
LEFRANCQ,Lefrancq,fr
LEFRANCQ,Lefrancq,nl
LEGRAND,Legrand,fr
LEGRAND,Legrand,nl
LEKAERTS,Lekaerts,fr
LEKAERTS,Lekaerts,nl
LEMAN,Leman,fr
LEMAN,Leman,nl
LEMONNIER,Lemonnier,fr
LEMONNIER,Lemonnier,nl
LENNEKE MARE,Lenneke Mare,fr
LENNEKE MARE,Lenneke Mare,nl
LENOIR,Lenoir,fr
LENOIR,Lenoir,nl
LEOPOLD I,Léopold I,fr
LEOPOLD I,Leopold I,nl
LEOPOLD II,Léopold II,fr
LEOPOLD II,Leopold II,nl
LEOPOLD III,Léopold III,fr
LEOPOLD III,Leopold III,nl
LEPOUTRE,Lepoutre,fr
LEPOUTRE,Lepoutre,nl
LEROY,Leroy,fr
LEROY,Leroy,nl
LES 3 TILLEULS,Les Trois Tilleuls,fr
LES 3 TILLEULS,Drie Linden,nl
LEVIE,Levie,fr
LEVIE,Levie,nl
LEVURE,Levure,fr
LEVURE,Gist,nl
LIBERTE,Liberté,fr
LIBERTE,Vrijheid,nl
LIEDTS,Liedts,fr
LIEDTS,Liedts,nl
LIMITE,Limite,fr
LIMITE,Grens,nl
LIVERPOOL,Liverpool,fr
LIVERPOOL,Liverpool,nl
LIVINGSTONE,Livingstone,fr
LIVINGSTONE,Livingstone,nl
LOISIRS,Loisirs,fr
LOISIRS,Vrijetijd,nl
LOMBARDIE,Lombardie,fr
LOMBARDIE,Lombardije,nl
LONDRES,Londres,fr
LONDRES,Londen,nl
LONG BONNIER,Long Bonnier,fr
LONG BONNIER,Lange Bunder,nl
LONG-CHENE,Long-Chêne,fr
LONG-CHENE,Lange Eik,nl
LONGCHAMP,Longchamp,fr
LONGCHAMP,Longchamp,nl
LORGE,Lorge,fr
LORGE,Lorge,nl
LOT STATION,Lot Station,fr
LOT STATION,Lot Station,nl
LOUIS BERTRAND,Louis Bertrand,fr
LOUIS BERTRAND,Louis Bertrand,nl
LOUIS HAP,Louis Hap,fr
LOUIS HAP,Louis Hap,nl
LOUIS MARCELIS,Louis Marcelis,fr
LOUIS MARCELIS,Louis Marcelis,nl
LOUISE,Louise,fr
LOUISE,Louiza,nl
LOUTRIER,Loutrier,fr
LOUTRIER,Ottervanger,nl
LOWET,Lowet,fr
LOWET,Lowet,nl
LOYAUTE,Loyauté,fr
LOYAUTE,Rechtschapenheid,nl
LUTHER,Luther,fr
LUTHER,Luther,nl
LUXEMBOURG,Luxembourg,fr
LUXEMBOURG,Luxemburg,nl
MA CAMPAGNE,Ma Campagne,fr
MA CAMPAGNE,Ma Campagne,nl
MABRU,Mabru,fr
MABRU,Mabru,nl
MACHELEN,Machelen,fr
MACHELEN,Machelen,nl
MACHTENS,Machtens,fr
MACHTENS,Machtens,nl
MADOU,Madou,fr
MADOU,Madou,nl
MADOUX,Madoux,fr
MADOUX,Madoux,nl
MAELBEEK,Maelbeek,fr
MAELBEEK,Maalbeek,nl
MAES,Maes,fr
MAES,Maes,nl
MAI,Mai,fr
MAI,Mei,nl
MAISON D'ERASME,Maison d'Erasme,fr
MAISON D'ERASME,Erasmushuis,nl
MALIBRAN,Malibran,fr
MALIBRAN,Malibran,nl
MANNEKEN-PIS,Manneken-Pis,fr
MANNEKEN-PIS,Manneken-Pis,nl
MANOIR D'ANJOU,Manoir d'Anjou,fr
MANOIR D'ANJOU,Manoir d'Anjou,nl
MARCEL THIRY,Marcel Thiry,fr
MARCEL THIRY,Marcel Thiry,nl
MAREYDE,Mareyde,fr
MAREYDE,Mareyde,nl
MARGUERITE,Marguerite,fr
MARGUERITE,Margareta,nl
MARICOLLES,Maricolles,fr
MARICOLLES,Maricollen,nl
MARIE-JOSE,Marie-José,fr
MARIE-JOSE,Marie-José,nl
MARIUS RENARD,Marius Renard,fr
MARIUS RENARD,Marius Renard,nl
MARLOW,Marlow,fr
MARLOW,Marlow,nl
MARLY,Marly,fr
MARLY,Marly,nl
MARMOTTE,Marmotte,fr
MARMOTTE,Marmot,nl
MASUI,Masui,fr
MASUI,Masui,nl
MATISSE,Matisse,fr
MATISSE,Matisse,nl
MAX WALLER,Max Waller,fr
MAX WALLER,Max Waller,nl
MAX-PLASKY,Max-Plasky,fr
MAX-PLASKY,Max-Plasky,nl
MEIR,Meir,fr
MEIR,Meir,nl
MEISER,Meiser,fr
MEISER,Meiser,nl
MELARD,Melard,fr
MELARD,Melard,nl
MENNEKENS,Mennekens,fr
MENNEKENS,Mennekens,nl
MERCATOR,Mercator,fr
MERCATOR,Mercator,nl
MERCHTEM,Merchtem,fr
MERCHTEM,Merchtem,nl
MERCURE,Mercure,fr
MERCURE,Mercurius,nl
MERIDIEN,Méridien,fr
MERIDIEN,Middaglijn,nl
MERLO,Merlo,fr
MERLO,Merlo,nl
MERODE,Merode,fr
MERODE,Merode,nl
MERTENS,Mertens,fr
MERTENS,Mertens,nl
MESSIDOR,Messidor,fr
MESSIDOR,Messidor,nl
MEUDON,Meudon,fr
MEUDON,Meudon,nl
MICHEL-ANGE,Michel-Ange,fr
MICHEL-ANGE,Michelangelo,nl
MICHIELS,Michiels,fr
MICHIELS,Michiels,nl
MIDDELWEG,Middelweg,fr
MIDDELWEG,Middelweg,nl
MINNEMOLEN,Minnemolen,fr
MINNEMOLEN,Minnemolen,nl
MIRAVAL,Miraval,fr
MIRAVAL,Miraval,nl
MIROIR,Miroir,fr
MIROIR,Spiegel,nl
MOENSBERG GARE,Moensberg Gare,fr
MOENSBERG GARE,Moensberg Station,nl
MOLIERE,Molière,fr
MOLIERE,Molière,nl
MOLIERE-LONGCHAMP,Molière-Longchamp,fr
MOLIERE-LONGCHAMP,Molière-Longchamp,nl
MOMMAERTS,Mommaerts,fr
MOMMAERTS,Mommaerts,nl
MONACO,Monaco,fr
MONACO,Monaco,nl
MONNOYER,Monnoyer,fr
MONNOYER,Monnoyer,nl
MONT KEMMEL,Mont Kemmel,fr
MONT KEMMEL,Kemmelberg,nl
MONTALD,Montald,fr
MONTALD,Montald,nl
MONTANA,Montana,fr
MONTANA,Montana,nl
MONTGOMERY,Montgomery,fr
MONTGOMERY,Montgomery,nl
MONTJOIE,Montjoie,fr
MONTJOIE,Montjoie,nl
MOONENS,Moonens,fr
MOONENS,Moonens,nl
MOORSLEDE,Moorslede,fr
MOORSLEDE,Moorslede,nl
MOORTEBEEK,Moortebeek,fr
MOORTEBEEK,Moortebeek,nl
MORIS,Moris,fr
MORIS,Moris,nl
MOSTINCK,Mostinck,fr
MOSTINCK,Mostinck,nl
MOUETTES,Mouettes,fr
MOUETTES,Meeuwen,nl
MOUNIER,Mounier,fr
MOUNIER,Mounier,nl
MOZART,Mozart,fr
MOZART,Mozart,nl
MUSEE D'IXELLES,Musée d'Ixelles,fr
MUSEE D'IXELLES,Museum van Elsene,nl
MUSEE DU TRAM,Musée du Tram,fr
MUSEE DU TRAM,Trammuseum,nl
MUSEUM,Museum,fr
MUSEUM,Museum,nl
MYSTERE,Mystère,fr
MYSTERE,Mysterie,nl
NAPOLEON,Napoléon,fr
NAPOLEON,Napoléon,nl
NATATION,Natation,fr
NATATION,Zwemkunst,nl
NEERPEDE,Neerpede,fr
NEERPEDE,Neerpede,nl
NEERSTALLE,Neerstalle,fr
NEERSTALLE,Neerstalle,nl
NEKKERSDAL,Nekkersdal,fr
NEKKERSDAL,Nekkersdal,nl
NEREUS,Nereus,fr
NEREUS,Nereus,nl
NERVIENS,Nerviens,fr
NERVIENS,Nerviërs,nl
NEUBERGER,Neuberger,fr
NEUBERGER,Neuberger,nl
NICOLAY,Nicolay,fr
NICOLAY,Nicolay,nl
NOTRE-DAME,Notre-Dame,fr
NOTRE-DAME,Onze-Lieve-Vrouw,nl
OBSERVATOIRE,Observatoire,fr
OBSERVATOIRE,Sterrenwacht,nl
OCEAN ATLANTIQUE,Océan Atlantique,fr
OCEAN ATLANTIQUE,Atlantische Oceaan,nl
ODON WARLAND,Odon Warland,fr
ODON WARLAND,Odon Warland,nl
OMNISPORTS HAREN,Omnisports Haren,fr
OMNISPORTS HAREN,Omnisport Haren,nl
ONZE NOVEMBRE,Onze Novembre,fr
ONZE NOVEMBRE,Elf November,nl
OPALE,Opale,fr
OPALE,Opaal,nl
OPPEM,Oppem,fr
OPPEM,Oppem,nl
OPPEMSTRAAT,Oppemstraat,fr
OPPEMSTRAAT,Oppemstraat,nl
OPTIMISME,Optimisme,fr
OPTIMISME,Optimisme,nl
ORBAN,Orban,fr
ORBAN,Orban,nl
OSSEGHEM,Osseghem,fr
OSSEGHEM,Ossegem,nl
OUD KAPELLEKE,Oud Kapelleke,fr
OUD KAPELLEKE,Oud Kapelleke,nl
OUTRE-PONTS,Outre-Ponts,fr
OUTRE-PONTS,Over de Bruggen,nl
PADDOCK,Paddock,fr
PADDOCK,Paddock,nl
PADUWA,Paduwa,fr
PADUWA,Paduwa,nl
PAGODES,Pagodes,fr
PAGODES,Pagoden,nl
PAIX,Paix,fr
PAIX,Vrede,nl
PALAIS,Palais,fr
PALAIS,Paleizen,nl
PALFYN,Palfyn,fr
PALFYN,Palfyn,nl
PANNENHUIS,Pannenhuis,fr
PANNENHUIS,Pannenhuis,nl
PAPENKASTEEL,Papenkasteel,fr
PAPENKASTEEL,Papenkasteel,nl
PARC,Parc,fr
PARC,Park,nl
PARC DES SOURCES,Parc des Sources,fr
PARC DES SOURCES,Bronnenpark,nl
PARC ELISABETH,Parc Élisabeth,fr
PARC ELISABETH,Elisabethpark,nl
PARC LEOPOLD,Parc Léopold,fr
PARC LEOPOLD,Leopoldspark,nl
PARC MALOU,Parc Malou,fr
PARC MALOU,Maloupark,nl
PARC MONNET,Parc Monnet,fr
PARC MONNET,Monnet-park,nl
PARC SENY,Parc Seny,fr
PARC SENY,Seny-park,nl
PARC VIVES,Parc Vivès,fr
PARC VIVES,Vivès-park,nl
PARKSTRAAT,Parkstraat,fr
PARKSTRAAT,Parkstraat,nl
PARVIS ST-GILLES,Parvis Saint-Gilles,fr
PARVIS ST-GILLES,Sint-Gillisvoorplein,nl
PASTEUR,Pasteur,fr
PASTEUR,Pasteur,nl
PATHE,Pathé,fr
PATHE,Pathé,nl
PATRIE,Patrie,fr
PATRIE,Vaderland,nl
PATTIJN,Pattijn,fr
PATTIJN,Pattijn,nl
PATTON,Patton,fr
PATTON,Patton,nl
PAUL LEDUC,Paul Leduc,fr
PAUL LEDUC,Paul Leduc,nl
PAULSEN,Paulsen,fr
PAULSEN,Paulsen,nl
PAVILLON,Pavillon,fr
PAVILLON,Paviljoen,nl
PAVILLONS MEUDON,Pavillons Meudon,fr
PAVILLONS MEUDON,Meudon-paviljoenen,nl
PEAGE,Péage,fr
PEAGE,Tol,nl
PECHERIES,Pêcheries,fr
PECHERIES,Visserij,nl
PELLENBERG,Pellenberg,fr
PELLENBERG,Pellenberg,nl
PENTATHLON,Pentathlon,fr
PENTATHLON,Pentathlon,nl
PERMEKE,Permeke,fr
PERMEKE,Permeke,nl
PETER BENOIT,Peter Benoit,fr
PETER BENOIT,Peter Benoit,nl
PETERBOS,Peterbos,fr
PETERBOS,Peterbos,nl
PETILLON,Pétillon,fr
PETILLON,Pétillon,nl
PETIT SABLON,Petit Sablon,fr
PETIT SABLON,Kleine Zavel,nl
PETITE ILE,Petite Île,fr
PETITE ILE,Klein Eiland,nl
PEUPLIERS,Peupliers,fr
PEUPLIERS,Populieren,nl
PEYO,Peyo,fr
PEYO,Peyo,nl
PICARD,Picard,fr
PICARD,Picard,nl
PICARDIE,Picardie,fr
PICARDIE,Picardie,nl
PLACE DE L'EGLISE,Place de l'Église,fr
PLACE DE L'EGLISE,Kerkplein,nl
PLACE R. ASTRID,Place Reine Astrid,fr
PLACE R. ASTRID,Koningin Astridplein,nl
PLACE SAINT-JOB,Place Saint-Job,fr
PLACE SAINT-JOB,Sint-Jobplein,nl
PLACE ST-PIERRE,Place Saint-Pierre,fr
PLACE ST-PIERRE,Sint-Pietersplein,nl
PLACE V. HORTA,Place Victor Horta,fr
PLACE V. HORTA,Victor Hortaplein,nl
PLAINE DES SPORTS,Plaine des Sports,fr
PLAINE DES SPORTS,Sportplein,nl
PLASKY,Plasky,fr
PLASKY,Plasky,nl
PLEIADES,Pléiades,fr
PLEIADES,Plejaden,nl
POELAERT,Poelaert,fr
POELAERT,Poelaert,nl
POGGE,Pogge,fr
POGGE,Pogge,nl
POMMIER,Pommier,fr
POMMIER,Appelboom,nl
PONT ALBERT,Pont Albert,fr
PONT ALBERT,Albertbrug,nl
PORTE DE FLANDRE,Porte de Flandre,fr
PORTE DE FLANDRE,Vlaamsepoort,nl
PORTE DE HAL,Porte de Hal,fr
PORTE DE HAL,Hallepoort,nl
PORTE DE NAMUR,Porte de Namur,fr
PORTE DE NAMUR,Naamsepoort,nl
PORTE DE NINOVE,Porte de Ninove,fr
PORTE DE NINOVE,Ninoofsepoort,nl
POUCHKINE,Pouchkine,fr
POUCHKINE,Poesjkin,nl
PRES COMMUNS,Prés Communs,fr
PRES COMMUNS,Gemenebeemden,nl
PRESSE,Presse,fr
PRESSE,Drukpers,nl
PRINC. CLEMENTINE,Princesse Clémentine,fr
PRINC. CLEMENTINE,Prinses Clementina,nl
PRINC. ELISABETH,Princesse Élisabeth,fr
PRINC. ELISABETH,Prinses Elisabeth,nl
PRINCE D'ORANGE,Prince d'Orange,fr
PRINCE D'ORANGE,Prins van Oranje,nl
PRINCE DE LIEGE,Prince de Liège,fr
PRINCE DE LIEGE,Prins van Luik,nl
PRINCE LEOPOLD,Prince Léopold,fr
PRINCE LEOPOLD,Prins Leopold,nl
PRISON,Prison,fr
PRISON,Gevangenis,nl
PTE D'ANDERLECHT,Porte d'Anderlecht,fr
PTE D'ANDERLECHT,Anderlechtsepoort,nl
QUART.ST-BONIFACE,Quartier Saint-Boniface,fr
QUART.ST-BONIFACE,Sint-Bonifaaswijk,nl
QUATRE BRAS,Quatre Bras,fr
QUATRE BRAS,Vier Armen,nl
QUATRE-VENTS,Quatre-Vents,fr
QUATRE-VENTS,Vier Winden,nl
QUETELET,Quetelet,fr
QUETELET,Quetelet,nl
RACING,Racing,fr
RACING,Racing,nl
RADIUM,Radium,fr
RADIUM,Radium,nl
RAEDEMAEKERS,Raedemaekers,fr
RAEDEMAEKERS,Raedemaekers,nl
RAMIER,Ramier,fr
RAMIER,Bosduif,nl
RAVENSTEIN,Ravenstein,fr
RAVENSTEIN,Ravenstein,nl
REINE ASTRID,Reine Astrid,fr
REINE ASTRID,Koningin Astrid,nl
RELAIS,Relais,fr
RELAIS,Pleisterplaats,nl
RENE GOBERT,René Gobert,fr
RENE GOBERT,René Gobert,nl
RENE HENRY,René Henry,fr
RENE HENRY,René Henry,nl
RENIERS,Reniers,fr
RENIERS,Reniers,nl
RESERVOIR,Réservoir,fr
RESERVOIR,Vergaarbak,nl
RESISTANCE,Résistance,fr
RESISTANCE,Verzet,nl
RIBAUCOURT,Ribaucourt,fr
RIBAUCOURT,Ribaucourt,nl
RIETHUISEN,Riethuisen,fr
RIETHUISEN,Riethuisen,nl
RING 0,Ring 0,fr
RING 0,Ring 0,nl
RITTWEGER,Rittweger,fr
RITTWEGER,Rittweger,nl
RIVE DROITE,Rive Droite,fr
RIVE DROITE,Rechteroever,nl
RIVE GAUCHE,Rive Gauche,fr
RIVE GAUCHE,Linkeroever,nl
ROBIANO,Robiano,fr
ROBIANO,Robiano,nl
ROCHEFORT,Rochefort,fr
ROCHEFORT,Rochefort,nl
RODIN,Rodin,fr
RODIN,Rodin,nl
RODTS,Rodts,fr
RODTS,Rodts,nl
ROFFIAEN,Roffiaen,fr
ROFFIAEN,Roffiaen,nl
ROGIER,Rogier,fr
ROGIER,Rogier,nl
ROI BAUDOUIN,Roi Baudouin,fr
ROI BAUDOUIN,Koning Boudewijn,nl
ROI VAINQUEUR,Roi Vainqueur,fr
ROI VAINQUEUR,Koning Overwinnaar,nl
RONCES,Ronces,fr
RONCES,Braamstruiken,nl
ROND-PT SOUVERAIN,Rond-point du Souverain,fr
ROND-PT SOUVERAIN,Vorstrondpunt,nl
ROODEBEEK,Roodebeek,fr
ROODEBEEK,Roodebeek,nl
ROODENBERG,Roodenberg,fr
ROODENBERG,Rodenberg,nl
ROOSENDAEL,Roosendael,fr
ROOSENDAEL,Roosendael,nl
ROUGE-CLOITRE,Rouge-Cloître,fr
ROUGE-CLOITRE,Roodklooster,nl
ROYALE,Royale,fr
ROYALE,Koning,nl
RTL HOUSE,RTL House,fr
RTL HOUSE,RTL House,nl
RUBENS,Rubens,fr
RUBENS,Rubens,nl
RUE AU BOIS,Rue au Bois,fr
RUE AU BOIS,Bosstraat,nl
RUE LONGUE,Rue Longue,fr
RUE LONGUE,Langestraat,nl
RUE TRAVERSIERE,Rue Traversière,fr
RUE TRAVERSIERE,Dwarsstraat,nl
RUISBROEK CENTRUM,Ruisbroek Centrum,fr
RUISBROEK CENTRUM,Ruisbroek Centrum,nl
RUISSEAU,Ruisseau,fr
RUISSEAU,Beek,nl
SABCA,SABCA,fr
SABCA,SABCA,nl
SACRE-COEUR,Sacré-Cœur,fr
SACRE-COEUR,Heilig Hart,nl
SAINCTELETTE,Sainctelette,fr
SAINCTELETTE,Sainctelette,nl
SAINT-ANTOINE,Saint-Antoine,fr
SAINT-ANTOINE,Sint-Antonius,nl
SAINT-DENIS,Saint-Denis,fr
SAINT-DENIS,Sint-Denijs,nl
SAINT-GERY,Saint-Géry,fr
SAINT-GERY,Sint-Gorik,nl
SAINT-GUIDON,Saint-Guidon,fr
SAINT-GUIDON,Sint-Guido,nl
SAINT-JOSSE,Saint-Josse,fr
SAINT-JOSSE,Sint-Joost,nl
SAINT-LOUIS,Saint-Louis,fr
SAINT-LOUIS,Saint-Louis,nl
SAINT-VINCENT,Saint-Vincent,fr
SAINT-VINCENT,Sint-Vincentius,nl
SAINTE-ALIX,Sainte-Alix,fr
SAINTE-ALIX,Sint-Aleidis,nl
SAINTE-ALLIANCE,Sainte-Alliance,fr
SAINTE-ALLIANCE,Heilig Verbond,nl
SAINTE-ANNE,Sainte-Anne,fr
SAINTE-ANNE,Sint-Anna,nl
SAINTE-CATHERINE,Sainte-Catherine,fr
SAINTE-CATHERINE,Sint-Katelijne,nl
SAINTE-FAMILLE,Sainte-Famille,fr
SAINTE-FAMILLE,Heilige Familie,nl
SAINTE-MARIE,Sainte-Marie,fr
SAINTE-MARIE,Sint-Maria,nl
SAO,SAO,fr
SAO,DOO,nl
SAVONNERIE,Savonnerie,fr
SAVONNERIE,Zeepziederij,nl
SCHAERBEEK GARE,Schaerbeek Gare,fr
SCHAERBEEK GARE,Schaarbeek Station,nl
SCHERDEMAEL,Scherdemael,fr
SCHERDEMAEL,Scherdemaal,nl
SCHOLA EUROPEA,Schola Europea,fr
SCHOLA EUROPEA,Schola Europea,nl
SCHOONEJANS,Schoonejans,fr
SCHOONEJANS,Schoonejans,nl
SCHUMAN,Schuman,fr
SCHUMAN,Schuman,nl
SCHWEITZER,Schweitzer,fr
SCHWEITZER,Schweitzer,nl
SCIENCE,Science,fr
SCIENCE,Wetenschap,nl
SEPT ETOILES,Sept Étoiles,fr
SEPT ETOILES,Zeven Sterren,nl
SERRES ROYALES,Serres Royales,fr
SERRES ROYALES,Koninklijke Serres,nl
SIBELIUS,Sibelius,fr
SIBELIUS,Sibelius,nl
SIMONIS,Simonis,fr
SIMONIS,Simonis,nl
SIMONIS TERMINUS,Simonis,fr
SIMONIS TERMINUS,Simonis,nl
SIMPSON,Simpson,fr
SIMPSON,Simpson,nl
SIPPELBERG,Sippelberg,fr
SIPPELBERG,Sippelberg,nl
SLEGERS,Slegers,fr
SLEGERS,Slegers,nl
SOBIESKI,Sobieski,fr
SOBIESKI,Sobieski,nl
SOLBOSCH,Solbosch,fr
SOLBOSCH,Solbos,nl
SORENSEN,Sorensen,fr
SORENSEN,Sorensen,nl
SPEECKAERT,Speeckaert,fr
SPEECKAERT,Speeckaert,nl
SPORTCENTRUM,Sportcentrum,fr
SPORTCENTRUM,Sportcentrum,nl
SPORTCOMPLEX,Sportcomplex,fr
SPORTCOMPLEX,Sportcomplex,nl
SQ. DU CENTENAIRE,Square du Centenaire,fr
SQ. DU CENTENAIRE,Eeuwfeestsquare,nl
STADE,Stade,fr
STADE,Stadion,nl
STADE FALLON,Stade Fallon,fr
STADE FALLON,Fallon Stadion,nl
STALLAERT,Stallaert,fr
STALLAERT,Stallaert,nl
STALLE (P),Stalle (P),fr
STALLE (P),Stalle (P),nl
STATION LOT,Station Lot,fr
STATION LOT,Station Lot,nl
STATUAIRES,Statuaires,fr
STATUAIRES,Beeldhouwers,nl
STEAMERS,Steamers,fr
STEAMERS,Stoomboten,nl
STEPHANIE,Stéphanie,fr
STEPHANIE,Stefania,nl
STEPHENSON,Stephenson,fr
STEPHENSON,Stephenson,nl
STEURS,Steurs,fr
STEURS,Steurs,nl
STIENON,Stiénon,fr
STIENON,Stiénon,nl
STIJN STREUVELS,Stijn Streuvels,fr
STIJN STREUVELS,Stijn Streuvels,nl
STOCKEL,Stockel,fr
STOCKEL,Stokkel,nl
STRATEGIE,Stratégie,fr
STRATEGIE,Krijgskunde,nl
STUYVENBERGH,Stuyvenbergh,fr
STUYVENBERGH,Stuyvenbergh,nl
SUEDE,Suède,fr
SUEDE,Zweden,nl
TAMARIS,Tamaris,fr
TAMARIS,Tamarisken,nl
TENREUKEN,Tenreuken,fr
TENREUKEN,Tenreuken,nl
TER MEEREN,Ter Meeren,fr
TER MEEREN,Ter Meeren,nl
TERCOIGNE,Tercoigne,fr
TERCOIGNE,Tercoigne,nl
TERVUREN STATION,Tervuren Station,fr
TERVUREN STATION,Tervuren Station,nl
THEVENET,Thévenet,fr
THEVENET,Thévenet,nl
THIEFFRY,Thieffry,fr
THIEFFRY,Thieffry,nl
THIRY-WOLUWE,Thiry-Woluwe,fr
THIRY-WOLUWE,Thiry-Woluwe,nl
THOMAS,Thomas,fr
THOMAS,Thomas,nl
THUMAS,Thumas,fr
THUMAS,Thumas,nl
THYM,Thym,fr
THYM,Tijm,nl
THYS,Thys,fr
THYS,Thys,nl
TILLEUL,Tilleul,fr
TILLEUL,Linde,nl
TIMMERMANS,Timmermans,fr
TIMMERMANS,Timmermans,nl
TIR AUX PIGEONS,Tir aux Pigeons,fr
TIR AUX PIGEONS,Duivenschieting,nl
TIRCHER,Tircher,fr
TIRCHER,Tircher,nl
TOMBERG,Tomberg,fr
TOMBERG,Tomberg,nl
TOULOUSE,Toulouse,fr
TOULOUSE,Toulouse,nl
TOUR ET TAXIS,Tour et Taxis,fr
TOUR ET TAXIS,Thurn en Taxis,nl
TOURNOI,Tournoi,fr
TOURNOI,Steekspel,nl
TRANSVAAL,Transvaal,fr
TRANSVAAL,Transvaal,nl
TRASSERSWEG,Trassersweg,fr
TRASSERSWEG,Trassersweg,nl
TREURENBERG,Treurenberg,fr
TREURENBERG,Treurenberg,nl
TREVES,Trêves,fr
TREVES,Trier,nl
TRIANGLE,Triangle,fr
TRIANGLE,Driehoek,nl
TRINITE,Trinité,fr
TRINITE,Drievuldigheid,nl
TRITOMAS,Tritomas,fr
TRITOMAS,Tritoma,nl
TROIS ARBRES,Trois Arbres,fr
TROIS ARBRES,Drie Bomen,nl
TROIS COULEURS,Trois Couleurs,fr
TROIS COULEURS,Drie Kleuren,nl
TROIS PERTUIS,Trois Pertuis,fr
TROIS PERTUIS,Driegaten,nl
TRONE,Trône,fr
TRONE,Troon,nl
TWEE LEEUWENWEG,Twee Leeuwenweg,fr
TWEE LEEUWENWEG,Twee Leeuwenweg,nl
TWYENINCK,Twyeninck,fr
TWYENINCK,Twyeninck,nl
UCCLE CALEVOET,Uccle Calevoet,fr
UCCLE CALEVOET,Ukkel Kalevoet,nl
UCCLE SPORT,Uccle Sport,fr
UCCLE SPORT,Ukkel Sport,nl
UCL SAINT-LUC,UCL Saint-Luc,fr
UCL SAINT-LUC,UCL Saint-Luc,nl
ULB,ULB,fr
ULB,ULB,nl
UNION,Union,fr
UNION,Union,nl
UZ BRUSSEL,UZ Brussel,fr
UZ BRUSSEL,UZ Brussel,nl
UZ-PEDIATRIE,UZ-Pédiatrie,fr
UZ-PEDIATRIE,UZ-Pediatrie,nl
UZ-VUB,UZ-VUB,fr
UZ-VUB,UZ-VUB,nl
VAL DES SEIGNEURS,Val des Seigneurs,fr
VAL DES SEIGNEURS,Herendal,nl
VAL MARIA,Val Maria,fr
VAL MARIA,Mariëndaal,nl
VALDUC,Valduc,fr
VALDUC,Hertogendal,nl
VALIDA,Valida,fr
VALIDA,Valida,nl
VAN BEETHOVEN,van Beethoven,fr
VAN BEETHOVEN,van Beethoven,nl
VAN BEVER,Van Bever,fr
VAN BEVER,Van Bever,nl
VAN CUTSEM,Van Cutsem,fr
VAN CUTSEM,Van Cutsem,nl
VAN EYCK,Van Eyck,fr
VAN EYCK,Van Eyck,nl
VAN HAELEN,Van Haelen,fr
VAN HAELEN,Van Haelen,nl
VAN KALKEN,van Kalken,fr
VAN KALKEN,van Kalken,nl
VAN PAGE,Van Page,fr
VAN PAGE,Van Page,nl
VAN PRAET,Van Praet,fr
VAN PRAET,Van Praet,nl
VAN ZANDE,Van Zande,fr
VAN ZANDE,Van Zande,nl
VANDENHOVEN,Vandenhoven,fr
VANDENHOVEN,Vandenhoven,nl
VANDER ELST,Vander Elst,fr
VANDER ELST,Vander Elst,nl
VANDER MEERSCHEN,Vander Meerschen,fr
VANDER MEERSCHEN,Vander Meerschen,nl
VANDERKINDERE,Vanderkindere,fr
VANDERKINDERE,Vanderkindere,nl
VANDERSTICHELEN,Vanderstichelen,fr
VANDERSTICHELEN,Vanderstichelen,nl
VANDERVELDE,Vandervelde,fr
VANDERVELDE,Vandervelde,nl
VANDROMME,Vandromme,fr
VANDROMME,Vandromme,nl
VANHELLEMONT,Vanhellemont,fr
VANHELLEMONT,Vanhellemont,nl
VANHUFFEL,Vanhuffel,fr
VANHUFFEL,Vanhuffel,nl
VANNE,Vanne,fr
VANNE,Verlaat,nl
VARIA,Varia,fr
VARIA,Varia,nl
VEEWEYDE,Veeweyde,fr
VEEWEYDE,Veeweide,nl
VERBEYST,Verbeyst,fr
VERBEYST,Verbeyst,nl
VERBOEKHOVEN,Verboekhoven,fr
VERBOEKHOVEN,Verboekhoven,nl
VEREMAN,Vereman,fr
VEREMAN,Vereman,nl
VERGOTE,Vergote,fr
VERGOTE,Vergote,nl
VERHEYLEWEGHEN,Verheyleweghen,fr
VERHEYLEWEGHEN,Verheyleweghen,nl
VERREWINKEL,Verrewinkel,fr
VERREWINKEL,Verrewinkel,nl
VERSAILLES,Versailles,fr
VERSAILLES,Versailles,nl
VERT CHASSEUR,Vert Chasseur,fr
VERT CHASSEUR,Groene Jager,nl
VETERANS COLON.,Vétérans Coloniaux,fr
VETERANS COLON.,Koloniale Veteranen,nl
VETERINAIRES,Vétérinaires,fr
VETERINAIRES,Veeartsen,nl
VIADUC E40,Viaduc E40,fr
VIADUC E40,Viaduct E40,nl
VICTOR ALLARD,Victor Allard,fr
VICTOR ALLARD,Victor Allard,nl
VICTOR HUGO,Victor Hugo,fr
VICTOR HUGO,Victor Hugo,nl
VIER HUISKENS,Vier Huiskens,fr
VIER HUISKENS,Vier Huiskens,nl
VIEUX CHEMIN,Vieux Chemin,fr
VIEUX CHEMIN,Oude Weg,nl
VIGNETTE,Vignette,fr
VIGNETTE,Kleine Wijngaard,nl
VILLON,Villon,fr
VILLON,Villon,nl
VILVOORDE STATION,Vilvoorde Station,fr
VILVOORDE STATION,Vilvoorde Station,nl
VINCOTTE,Vinçotte,fr
VINCOTTE,Vinçotte,nl
VIOLETTES,Violettes,fr
VIOLETTES,Viooltjes,nl
VIVIER D'OIE,Vivier d'Oie,fr
VIVIER D'OIE,Diesdelle,nl
VLEURGAT,Vleurgat,fr
VLEURGAT,Vleurgat,nl
VLIERKENS,Vlierkens,fr
VLIERKENS,Vlierkens,nl
VOETBALCLUB,Voetbalclub,fr
VOETBALCLUB,Voetbalclub,nl
VOISINS,Voisins,fr
VOISINS,Geburen,nl
VOOT,Voot,fr
VOOT,Voot,nl
VTM,VTM,fr
VTM,VTM,nl
VUB,VUB,fr
VUB,VUB,nl
WAELHEM,Waelhem,fr
WAELHEM,Waelhem,nl
WAGON,Wagon,fr
WAGON,Wagen,nl
WAPPERS,Wappers,fr
WAPPERS,Wappers,nl
WASHINGTON,Washington,fr
WASHINGTON,Washington,nl
WATERBURY,Waterbury,fr
WATERBURY,Waterbury,nl
WATERLOO WILSON,Waterloo Wilson,fr
WATERLOO WILSON,Waterloo Wilson,nl
WATERMAEL GARE,Watermael Gare,fr
WATERMAEL GARE,Watermaal Station,nl
WAUTERS,Wauters,fr
WAUTERS,Wauters,nl
WAXWEILER,Waxweiler,fr
WAXWEILER,Waxweiler,nl
WERY,Wery,fr
WERY,Wery,nl
WESTLAND SHOPPING,Westland Shopping,fr
WESTLAND SHOPPING,Westland Shopping,nl
WEZEMBEEK-SHOP.,Wezembeek-Shopping,fr
WEZEMBEEK-SHOP.,Wezembeek-Shopping,nl
WIELS,Wiels,fr
WIELS,Wiels,nl
WIENER,Wiener,fr
WIENER,Wiener,nl
WILLEBROEK,Willebroek,fr
WILLEBROEK,Willebroek,nl
WILLEMYNS,Willemyns,fr
WILLEMYNS,Willemyns,nl
WITLOOF,Witloof,fr
WITLOOF,Witloof,nl
WOESTE,Woeste,fr
WOESTE,Woeste,nl
WOLUWE SHOPPING,Woluwe Shopping,fr
WOLUWE SHOPPING,Woluwe Shopping,nl
WOLVENDAEL,Wolvendael,fr
WOLVENDAEL,Wolvendael,nl
WTC,WTC,fr
WTC,WTC,nl
XAVIER DE BUE,Xavier de Bue,fr
XAVIER DE BUE,Xavier de Bue,nl
YPRES,Ypres,fr
YPRES,Ieper,nl
YSAYE,Ysaye,fr
YSAYE,Ysaye,nl
YSER,Yser,fr
YSER,IJzer,nl
ZAMAN-FOREST NAT.,Zaman-Forest National,fr
ZAMAN-FOREST NAT.,Zaman-Vorst Nationaal,nl
ZAVELPUT,Zavelput,fr
ZAVELPUT,Zavelput,nl
ZEECRABBE,Zeecrabbe,fr
ZEECRABBE,Zeecrabbe,nl
ZENOBE GRAMME,Zénobe Gramme,fr
ZENOBE GRAMME,Zénobe Gramme,nl
ZEPHYR,Zéphyr,fr
ZEPHYR,Westenwind,nl
ALBERT - GARE DE LINKEBEEK,ALBERT - GARE DE LINKEBEEK,fr
ALBERT - GARE DE LINKEBEEK,ALBERT - LINKEBEEK STATION,nl
AMBIORIX - UCCLE CALEVOET,AMBIORIX - UCCLE CALEVOET,fr
AMBIORIX - UCCLE CALEVOET,AMBIORIX - UKKEL KALEVOET,nl
BEAULIEU - HEILIGENBORRE,BEAULIEU - HEILIGENBORRE,fr
BEAULIEU - HEILIGENBORRE,BEAULIEU - HEILIGENBORRE,nl
BERCHEM STATION - DROGENBOS CHATEAU,BERCHEM STATION - DROGENBOS CHATEAU,fr
BERCHEM STATION - DROGENBOS CHATEAU,BERCHEM STATION - DROGENBOS KASTEEL,nl
BERCHEM STATION - HEYSEL,BERCHEM STATION - HEYSEL,fr
BERCHEM STATION - HEYSEL,BERCHEM STATION - HEIZEL,nl
BOONDAEL GARE - ROGIER,BOONDAEL GARE - ROGIER,fr
BOONDAEL GARE - ROGIER,BOONDAAL STATION - ROGIER,nl
BRABANCONNE - KONKEL,BRABANCONNE - KONKEL,fr
BRABANCONNE - KONKEL,BRABANCONNE - KONKEL,nl
BRUSSELS AIRPORT - BRUSSELS CITY,BRUSSELS AIRPORT - BRUSSELS CITY,fr
BRUSSELS AIRPORT - BRUSSELS CITY,BRUSSELS AIRPORT - BRUSSELS CITY,nl
BRUSSELS AIRPORT - LUXEMBOURG,BRUSSELS AIRPORT - LUXEMBOURG,fr
BRUSSELS AIRPORT - LUXEMBOURG,BRUSSELS AIRPORT - LUXEMBURG,nl
CAMPUS CERIA - BON AIR,CAMPUS CERIA - BON AIR,fr
CAMPUS CERIA - BON AIR,CAMPUS COOVI - GOEDE LUCHT,nl
CERIA - HEROS,CERIA - HEROS,fr
CERIA - HEROS,COOVI - HELDEN,nl
DA VINCI - DROGENBOS CHATEAU,DA VINCI - DROGENBOS CHATEAU,fr
DA VINCI - DROGENBOS CHATEAU,DA VINCI - DROGENBOS KASTEEL,nl
DA VINCI - ROGIER,DA VINCI - ROGIER,fr
DA VINCI - ROGIER,DA VINCI - ROGIER,nl
DANSAERT - LOUISE,DANSAERT - LOUISE,fr
DANSAERT - LOUISE,DANSAERT - LOUIZA,nl
DE BROUCKERE - DELTA,DE BROUCKERE - DELTA,fr
DE BROUCKERE - DELTA,DE BROUCKERE - DELTA,nl
DE BROUCKERE - HEYSEL,DE BROUCKERE - HEYSEL,fr
DE BROUCKERE - HEYSEL,DE BROUCKERE - HEIZEL,nl
DE BROUCKERE - HOF TEN BERG,DE BROUCKERE - HOF TEN BERG,fr
DE BROUCKERE - HOF TEN BERG,DE BROUCKERE - HOF TEN BERG,nl
DE BROUCKERE - PEAGE,DE BROUCKERE - PEAGE,fr
DE BROUCKERE - PEAGE,DE BROUCKERE - TOL,nl
DE BROUCKERE - VILVOORDE STATION,DE BROUCKERE - VILVOORDE STATION,fr
DE BROUCKERE - VILVOORDE STATION,DE BROUCKERE - VILVOORDE STATION,nl
ERASME - HERRMANN-DEBROUX,ERASME - HERRMANN-DEBROUX,fr
ERASME - HERRMANN-DEBROUX,ERASMUS - HERRMANN-DEBROUX,nl
ESPLANADE - CHURCHILL,ESPLANADE - CHURCHILL,fr
ESPLANADE - CHURCHILL,ESPLANADE - CHURCHILL,nl
EUROCONTROL - CIMETIERE DE JETTE,EUROCONTROL - CIMETIERE DE JETTE,fr
EUROCONTROL - CIMETIERE DE JETTE,EUROCONTROL - KERKHOF VAN JETTE,nl
GARE CENTRALE - BERCHEM STATION,GARE CENTRALE - BERCHEM STATION,fr
GARE CENTRALE - BERCHEM STATION,CENTRAAL STATION - BERCHEM STATION,nl
GARE CENTRALE - BOURGET,GARE CENTRALE - BOURGET,fr
GARE CENTRALE - BOURGET,CENTRAAL STATION - BOURGET,nl
GARE CENTRALE - CARREFOUR STALLE,GARE CENTRALE - CARREFOUR STALLE,fr
GARE CENTRALE - CARREFOUR STALLE,CENTRAAL STATION - KRUISPUNT STALLE,nl
GARE CENTRALE - CIMETIERE DE BRUXELLES,GARE CENTRALE - CIMETIERE DE BRUXELLES,fr
GARE CENTRALE - CIMETIERE DE BRUXELLES,CENTRAAL STATION - BEGRAAFPLAATS VAN BRUSSEL,nl
GARE CENTRALE - FORT-JACO,GARE CENTRALE - FORT-JACO,fr
GARE CENTRALE - FORT-JACO,CENTRAAL STATION - FORT-JACO,nl
GARE CENTRALE - HEROS,GARE CENTRALE - HEROS,fr
GARE CENTRALE - HEROS,CENTRAAL STATION - HELDEN,nl
GARE CENTRALE - HERRMANN-DEBROUX,GARE CENTRALE - HERRMANN-DEBROUX,fr
GARE CENTRALE - HERRMANN-DEBROUX,CENTRAAL STATION - HERRMANN-DEBROUX,nl
GARE CENTRALE - HEYSEL,GARE CENTRALE - HEYSEL,fr
GARE CENTRALE - HEYSEL,CENTRAAL STATION - HEIZEL,nl
GARE CENTRALE - HOMBORCH,GARE CENTRALE - HOMBORCH,fr
GARE CENTRALE - HOMBORCH,CENTRAAL STATION - HOMBORCH,nl
GARE CENTRALE - KRAAINEM,GARE CENTRALE - KRAAINEM,fr
GARE CENTRALE - KRAAINEM,CENTRAAL STATION - KRAAINEM,nl
GARE CENTRALE - MUSEE DU TRAM,GARE CENTRALE - MUSEE DU TRAM,fr
GARE CENTRALE - MUSEE DU TRAM,CENTRAAL STATION - TRAMMUSEUM,nl
GARE CENTRALE - WESTLAND SHOPPING,GARE CENTRALE - WESTLAND SHOPPING,fr
GARE CENTRALE - WESTLAND SHOPPING,CENTRAAL STATION - WESTLAND SHOPPING,nl
GARE CENTRALE - WIENER,GARE CENTRALE - WIENER,fr
GARE CENTRALE - WIENER,CENTRAAL STATION - WIENER,nl
GARE DE L'OUEST - STOCKEL,GARE DE L'OUEST - STOCKEL,fr
GARE DE L'OUEST - STOCKEL,WESTSTATION - STOKKEL,nl
GARE DU MIDI - ANDROMEDE,GARE DU MIDI - ANDROMEDE,fr
GARE DU MIDI - ANDROMEDE,ZUIDSTATION - ANDROMEDA,nl
GARE DU MIDI - BOCKSTAEL,GARE DU MIDI - BOCKSTAEL,fr
GARE DU MIDI - BOCKSTAEL,ZUIDSTATION - BOCKSTAEL,nl
GARE DU MIDI - LOT STATION,GARE DU MIDI - LOT STATION,fr
GARE DU MIDI - LOT STATION,ZUIDSTATION - LOT STATION,nl
GARE DU NORD - HOPITAL MILITAIRE,GARE DU NORD - HOPITAL MILITAIRE,fr
GARE DU NORD - HOPITAL MILITAIRE,NOORDSTATION - MILITAIR HOSPITAAL,nl
GARE DU NORD - MONTGOMERY,GARE DU NORD - MONTGOMERY,fr
GARE DU NORD - MONTGOMERY,NOORDSTATION - MONTGOMERY,nl
GARE DU NORD - STALLE (P),GARE DU NORD - STALLE (P),fr
GARE DU NORD - STALLE (P),NOORDSTATION - STALLE (P),nl
GARE DU NORD - UZ-VUB,GARE DU NORD - UZ-VUB,fr
GARE DU NORD - UZ-VUB,NOORDSTATION - UZ-VUB,nl
GRAND-PLACE - DECROLY,GRAND-PLACE - DECROLY,fr
GRAND-PLACE - DECROLY,GROTE MARKT - DECROLY,nl
GRAND-PLACE - WIENER,GRAND-PLACE - WIENER,fr
GRAND-PLACE - WIENER,GROTE MARKT - WIENER,nl
GROOT-BIJGAARDEN - DE WAND,GROOT-BIJGAARDEN - DE WAND,fr
GROOT-BIJGAARDEN - DE WAND,GROOT-BIJGAARDEN - DE WAND,nl
HEROS - TRANSVAAL,HEROS - TRANSVAAL,fr
HEROS - TRANSVAAL,HELDEN - TRANSVAAL,nl
HOPITAL ETTERBEEK-IXELLES - BORDET STATION,HOPITAL ETTERBEEK-IXELLES - BORDET STATION,fr
HOPITAL ETTERBEEK-IXELLES - BORDET STATION,ZIEKH. ETTERBEEK-ELSENE - BORDET STATION,nl
HOPITAL MILITAIRE - UZ-VUB,HOPITAL MILITAIRE - UZ-VUB,fr
HOPITAL MILITAIRE - UZ-VUB,MILITAIR HOSPITAAL - UZ-VUB,nl
HUMANITE - GARE DU MIDI,HUMANITE - GARE DU MIDI,fr
HUMANITE - GARE DU MIDI,HUMANITEIT - ZUIDSTATION,nl
HUNDERENVELD - GARE DU NORD,HUNDERENVELD - GARE DU NORD,fr
HUNDERENVELD - GARE DU NORD,HUNDERENVELD - NOORDSTATION,nl
KRAAINEM - HIPPODROME,KRAAINEM - HIPPODROME,fr
KRAAINEM - HIPPODROME,KRAAINEM - HIPPODROOM,nl
KRAAINEM - OPPEM,KRAAINEM - OPPEM,fr
KRAAINEM - OPPEM,KRAAINEM - OPPEM,nl
KRAAINEM - SCHUMAN,KRAAINEM - SCHUMAN,fr
KRAAINEM - SCHUMAN,KRAAINEM - SCHUMAN,nl
LOUISE - DIEWEG,LOUISE - DIEWEG,fr
LOUISE - DIEWEG,LOUIZA - DIEWEG,nl
LOUISE - ROODEBEEK,LOUISE - ROODEBEEK,fr
LOUISE - ROODEBEEK,LOUIZA - ROODEBEEK,nl
MACHTENS - GARE CENTRALE,MACHTENS - GARE CENTRALE,fr
MACHTENS - GARE CENTRALE,MACHTENS - CENTRAAL STATION,nl
MARIUS RENARD - MONTGOMERY,MARIUS RENARD - MONTGOMERY,fr
MARIUS RENARD - MONTGOMERY,MARIUS RENARD - MONTGOMERY,nl
MONTGOMERY - BAN-EIK,MONTGOMERY - BAN-EIK,fr
MONTGOMERY - BAN-EIK,MONTGOMERY - BAN-EIK,nl
MONTGOMERY - TERVUREN STATION,MONTGOMERY - TERVUREN STATION,fr
MONTGOMERY - TERVUREN STATION,MONTGOMERY - TERVUREN STATION,nl
MOORTEBEEK - ANNEESSENS,MOORTEBEEK - ANNEESSENS,fr
MOORTEBEEK - ANNEESSENS,MOORTEBEEK - ANNEESSENS,nl
OBSERVATOIRE - VIVIER D'OIE,OBSERVATOIRE - VIVIER D'OIE,fr
OBSERVATOIRE - VIVIER D'OIE,STERRENWACHT - DIESDELLE,nl
PORTE DE NAMUR - MACHELEN,PORTE DE NAMUR - MACHELEN,fr
PORTE DE NAMUR - MACHELEN,NAAMSEPOORT - MACHELEN,nl
PORTE DE NAMUR - MAES,PORTE DE NAMUR - MAES,fr
PORTE DE NAMUR - MAES,NAAMSEPOORT - MAES,nl
PORTE DE NAMUR - SAINTE-ANNE,PORTE DE NAMUR - SAINTE-ANNE,fr
PORTE DE NAMUR - SAINTE-ANNE,NAAMSEPOORT - SINT-ANNA,nl
ROI BAUDOUIN - ELISABETH,ROI BAUDOUIN - ELISABETH,fr
ROI BAUDOUIN - ELISABETH,KONING BOUDEWIJN - ELISABETH,nl
ROODEBEEK - SAINT-VINCENT,ROODEBEEK - SAINT-VINCENT,fr
ROODEBEEK - SAINT-VINCENT,ROODEBEEK - SINT-VINCENTIUS,nl
SCHAERBEEK GARE - FORT-JACO,SCHAERBEEK GARE - FORT-JACO,fr
SCHAERBEEK GARE - FORT-JACO,SCHAARBEEK STATION - FORT-JACO,nl
SCHAERBEEK GARE - JULES BORDET,SCHAERBEEK GARE - JULES BORDET,fr
SCHAERBEEK GARE - JULES BORDET,SCHAARBEEK STATION - JULES BORDET,nl
SCHUMAN - KONKEL,SCHUMAN - KONKEL,fr
SCHUMAN - KONKEL,SCHUMAN - KONKEL,nl
SIMONIS - ARBRE BALLON,SIMONIS - ARBRE BALLON,fr
SIMONIS - ARBRE BALLON,SIMONIS - DIKKE BEUK,nl
SIMONIS - BEEKKANT,SIMONIS - BEEKKANT,fr
SIMONIS - BEEKKANT,SIMONIS - BEEKKANT,nl
SIMONIS - ELISABETH,SIMONIS - ELISABETH,fr
SIMONIS - ELISABETH,SIMONIS - ELISABETH,nl
SIMONIS - UZ-VUB,SIMONIS - UZ-VUB,fr
SIMONIS - UZ-VUB,SIMONIS - UZ-VUB,nl
STADE - LEGRAND,STADE - LEGRAND,fr
STADE - LEGRAND,STADION - LEGRAND,nl
STADE - VAN HAELEN,STADE - VAN HAELEN,fr
STADE - VAN HAELEN,STADION - VAN HAELEN,nl
TRONE - FOREST (BERVOETS),TRONE - FOREST (BERVOETS),fr
TRONE - FOREST (BERVOETS),TROON - VORST (BERVOETS),nl
ULB - ADEPS,ULB - ADEPS,fr
ULB - ADEPS,ULB - ADEPS,nl
VANDERKINDERE - HEYSEL,VANDERKINDERE - HEYSEL,fr
VANDERKINDERE - HEYSEL,VANDERKINDERE - HEIZEL,nl
VIADUC E40 - ROODEBEEK,VIADUC E40 - ROODEBEEK,fr
VIADUC E40 - ROODEBEEK,VIADUCT E40 - ROODEBEEK,nl
VILVOORDE STATION - YSER,VILVOORDE STATION - YSER,fr
VILVOORDE STATION - YSER,VILVOORDE STATION - IJZER,nl
WESTLAND SHOPPING - BOCKSTAEL,WESTLAND SHOPPING - BOCKSTAEL,fr
WESTLAND SHOPPING - BOCKSTAEL,WESTLAND SHOPPING - BOCKSTAEL,nl
4 - Boulevard Anspach,4 - Boulevard Anspach,fr
4 - Boulevard Anspach,4 - Anspachlaan,nl
2 - Place De Brouckère,2 - Place De Brouckère,fr
2 - Place De Brouckère,2 - De Brouckèreplein,nl
3 - Place De Brouckère,3 - Place De Brouckère,fr
3 - Place De Brouckère,3 - De Brouckèreplein,nl
1 - Place De Brouckère,1 - Place De Brouckère,fr
1 - Place De Brouckère,1 - De Brouckèreplein,nl
1 - Putterie,1 - Putterie,fr
1 - Putterie,1 - Putterij,nl
2 - Rue des Colonies,2 - Rue des Colonies,fr
2 - Rue des Colonies,2 - Koloniënstraat,nl
3 - Rue des Colonies,3 - Rue des Colonies,fr
3 - Rue des Colonies,3 - Koloniënstraat,nl
5 - Rue Montagne du Parc,5 - Rue Montagne du Parc,fr
5 - Rue Montagne du Parc,5 - Warandeberg,nl
6 - Putterie,6 - Putterie,fr
6 - Putterie,6 - Putterij,nl
1 - Rue Royale,1 - Rue Royale,fr
1 - Rue Royale,1 - Koningsstraat,nl
1 - Rue de la Loi,1 - Rue de la Loi,fr
1 - Rue de la Loi,1 - Wetstraat,nl
2 - Rue de la Loi,2 - Rue de la Loi,fr
2 - Rue de la Loi,2 - Wetstraat,nl
3 - Avenue des Arts,3 - Avenue des Arts,fr
3 - Avenue des Arts,3 - Kunstlaan,nl
4 - Avenue des Arts,4 - Avenue des Arts,fr
4 - Avenue des Arts,4 - Kunstlaan,nl
5 - Boulevard du Régent,5 - Boulevard du Régent,fr
5 - Boulevard du Régent,5 - Regentlaan,nl
6 - Boulevard du Régent,6 - Boulevard du Régent,fr
6 - Boulevard du Régent,6 - Regentlaan,nl
1 - Chaussée d'Etterbeek,1 - Chaussée d'Etterbeek,fr
1 - Chaussée d'Etterbeek,1 - Etterbeeksesteenweg,nl
3 - Rue de la Loi,3 - Rue de la Loi,fr
3 - Rue de la Loi,3 - Wetstraat,nl
4 - Rue Joseph II,4 - Rue Joseph II,fr
4 - Rue Joseph II,4 - Jozef II-straat,nl
5 - Rue de la Loi,5 - Rue de la Loi,fr
5 - Rue de la Loi,5 - Wetstraat,nl
3 - Rond-point Schuman,3 - Rond-point Schuman,fr
3 - Rond-point Schuman,3 - Robert Schumanplein,nl
2 - Rond-point Schuman,2 - Rond-point Schuman,fr
2 - Rond-point Schuman,2 - Robert Schumanplein,nl
1 - Avenue de l'Yser,1 - Avenue de l'Yser,fr
1 - Avenue de l'Yser,1 - IJzerlaan,nl
2 - Avenue de Tervuren,2 - Avenue de Tervuren,fr
2 - Avenue de Tervuren,2 - Tervurenlaan,nl
3 - Avenue des Celtes,3 - Avenue des Celtes,fr
3 - Avenue des Celtes,3 - Keltenlaan,nl
4 - Avenue des Gaulois,4 - Avenue des Gaulois,fr
4 - Avenue des Gaulois,4 - Galliërslaan,nl
7 - Square Princesse Jean de Mérode,7 - Square Princesse Jean de Mérode,fr
7 - Square Princesse Jean de Mérode,7 - Prinses Jean de Mérodeplein,nl
8 - Rue des Tongres,8 - Rue des Tongres,fr
8 - Rue des Tongres,8 - Tongerenstraat,nl
1 - Square Maréchal Montgomery,1 - Square Maréchal Montgomery,fr
1 - Square Maréchal Montgomery,1 - Maarschalk Montgomeryplein,nl
2 - Boulevard Saint-Michel,2 - Boulevard Saint-Michel,fr
2 - Boulevard Saint-Michel,2 - Sint-Michielslaan,nl
3 - Square Maréchal Montgomery,3 - Square Maréchal Montgomery,fr
3 - Square Maréchal Montgomery,3 - Maarschalk Montgomeryplein,nl
4 - Avenue de Tervuren,4 - Avenue de Tervuren,fr
4 - Avenue de Tervuren,4 - Tervurenlaan,nl
5 - Boulevard Brand Whitlock,5 - Boulevard Brand Whitlock,fr
5 - Boulevard Brand Whitlock,5 - Brand Whitlocklaan,nl
1 - Square Joséphine-Charlotte,1 - Square Joséphine-Charlotte,fr
1 - Square Joséphine-Charlotte,1 - Joséphine-Charlottesquare,nl
2 - Avenue de Woluwe-St-Lambert,2 - Avenue de Woluwe-St-Lambert,fr
2 - Avenue de Woluwe-St-Lambert,2 - Sint-Lambrechts-Woluwelaan,nl
3 - Avenue de Broqueville,3 - Avenue de Broqueville,fr
3 - Avenue de Broqueville,3 - de Broquevillelaan,nl
1 - Avenue du Roi Chevalier,1 - Avenue du Roi Chevalier,fr
1 - Avenue du Roi Chevalier,1 - Ridder Koninglaan,nl
2 - Avenue du Roi Chevalier,2 - Avenue du Roi Chevalier,fr
2 - Avenue du Roi Chevalier,2 - Ridder Koninglaan,nl
3 - Avenue Gribaumont,3 - Avenue Gribaumont,fr
3 - Avenue Gribaumont,3 - Louis Gribaumontlaan,nl
4 - Avenue Gribaumont,4 - Avenue Gribaumont,fr
4 - Avenue Gribaumont,4 - Louis Gribaumontlaan,nl
1 - Avenue Paul Hymans,1 - Avenue Paul Hymans,fr
1 - Avenue Paul Hymans,1 - Paul Hymanslaan,nl
2 - Avenue Paul Hymans,2 - Avenue Paul Hymans,fr
2 - Avenue Paul Hymans,2 - Paul Hymanslaan,nl
3 - Place du Tomberg,3 - Place du Tomberg,fr
3 - Place du Tomberg,3 - Tombergplein,nl
4 - Place du Tomberg,4 - Place du Tomberg,fr
4 - Place du Tomberg,4 - Tombergplein,nl
1 - Parking Roodebeek,1 - Parking Roodebeek,fr
1 - Parking Roodebeek,1 - Parking Roodebeek,nl
3 - Avenue Paul Hymans,3 - Avenue Paul Hymans,fr
3 - Avenue Paul Hymans,3 - Paul Hymanslaan,nl
4 - Woluwe Shopping Center,4 - Woluwe Shopping Center,fr
4 - Woluwe Shopping Center,4 - Woluwe Shopping Center,nl
5 - Avenue Paul Hymans,5 - Avenue Paul Hymans,fr
5 - Avenue Paul Hymans,5 - Paul Hymanslaan,nl
6 - Avenue Paul Hymans,6 - Avenue Paul Hymans,fr
6 - Avenue Paul Hymans,6 - Paul Hymanslaan,nl
1 - Avenue Emile Vandervelde,1 - Avenue Emile Vandervelde,fr
1 - Avenue Emile Vandervelde,1 - Emile Vanderveldelaan,nl
2 - Avenue Emile Vandervelde,2 - Avenue Emile Vandervelde,fr
2 - Avenue Emile Vandervelde,2 - Emile Vanderveldelaan,nl
3 - Place de l'Alma,3 - Place de l'Alma,fr
3 - Place de l'Alma,3 - Almaplein,nl
2 - Place de la Vecquée,2 - Place de la Vecquée,fr
2 - Place de la Vecquée,2 - Vècquéeplein,nl
1 - Avenue de Wezembeek,1 - Avenue de Wezembeek,fr
1 - Avenue de Wezembeek,1 - Wezembeeklaan,nl
1 - Square Stockel,1 - Square Stockel,fr
1 - Square Stockel,1 - Stokkel Square,nl
2 - Rue Dominique De Jonghe,2 - Rue Dominique De Jonghe,fr
2 - Rue Dominique De Jonghe,2 - Dominique De Jonghestraat,nl
1 - Pont Fernand Demany,1 - Pont Fernand Demany,fr
1 - Pont Fernand Demany,1 - Fernand Demanybrug,nl
2 - Pont Fernand Demany,2 - Pont Fernand Demany,fr
2 - Pont Fernand Demany,2 - Fernand Demanybrug,nl
1 - Avenue des Volontaires,1 - Avenue des Volontaires,fr
1 - Avenue des Volontaires,1 - Vrijwilligerslaan,nl
2 - Boulevard Louis Schimdt,2 - Boulevard Louis Schimdt,fr
2 - Boulevard Louis Schimdt,2 - Louis Schmidtlaan,nl
1 - Chaussée de Wavre,1 - Chaussée de Wavre,fr
1 - Chaussée de Wavre,1 - Waversesteenweg,nl
2 - Chaussée de Wavre,2 - Chaussée de Wavre,fr
2 - Chaussée de Wavre,2 - Waversesteenweg,nl
3 - Chaussée de Wavre,3 - Chaussée de Wavre,fr
3 - Chaussée de Wavre,3 - Waversesteenweg,nl
1 - Parking Delta,1 - Parking Delta,fr
1 - Parking Delta,1 - Parking Delta,nl
2 - Boulevard du Triomphe,2 - Boulevard du Triomphe,fr
2 - Boulevard du Triomphe,2 - Triomflaan,nl
3 - Boulevard des Invalides,3 - Boulevard des Invalides,fr
3 - Boulevard des Invalides,3 - Invalidenlaan,nl
4 - Rue Jules Cockx,4 - Rue Jules Cockx,fr
4 - Rue Jules Cockx,4 - Jules Cockxstraat,nl
1 - Rue Jules Cockx,1 - Rue Jules Cockx,fr
1 - Rue Jules Cockx,1 - Jules Cockxstraat,nl
2 - Rue Jules Cockx,2 - Rue Jules Cockx,fr
2 - Rue Jules Cockx,2 - Jules Cockxstraat,nl
3 - Avenue des Meuniers,3 - Avenue des Meuniers,fr
3 - Avenue des Meuniers,3 - Mulderslaan,nl
4 - Avenue des Meuniers,4 - Avenue des Meuniers,fr
4 - Avenue des Meuniers,4 - Mulderslaan,nl
5 - Rue Jules Cockx,5 - Rue Jules Cockx,fr
5 - Rue Jules Cockx,5 - Jules Cockxstraat,nl
1 - Avenue E.Van Nieuwenhuyse,1 - Avenue E.Van Nieuwenhuyse,fr
1 - Avenue E.Van Nieuwenhuyse,1 - Edmond van Nieuwenhuyselaan,nl
2 - Avenue Louis Dehoux,2 - Avenue Louis Dehoux,fr
2 - Avenue Louis Dehoux,2 - Louis Dehouxlaan,nl
3 - Avenue Louis Dehoux,3 - Avenue Louis Dehoux,fr
3 - Avenue Louis Dehoux,3 - Louis Dehouxlaan,nl
4 - Avenue Louis Dehoux,4 - Avenue Louis Dehoux,fr
4 - Avenue Louis Dehoux,4 - Louis Dehouxlaan,nl
5 - Avenue E.Van Nieuwenhuyse,5 - Avenue E.Van Nieuwenhuyse,fr
5 - Avenue E.Van Nieuwenhuyse,5 - Edmond van Nieuwenhuyselaan,nl
1 - Avenue Herrmann-Debroux,1 - Avenue Herrmann-Debroux,fr
1 - Avenue Herrmann-Debroux,1 - Herrmann-Debrouxlaan,nl
2 - Avenue Herrmann-Debroux,2 - Avenue Herrmann-Debroux,fr
2 - Avenue Herrmann-Debroux,2 - Herrmann-Debrouxlaan,nl
1 - Quai au Bois à Brûler,1 - Quai au Bois à Brûler,fr
1 - Quai au Bois à Brûler,1 - Brandhoutkaai,nl
1 - Quai aux Briques,1 - Quai aux Briques,fr
1 - Quai aux Briques,1 - Baksteenkaai,nl
1 - Rue du Comte de Flandre,1 - Rue du Comte de Flandre,fr
1 - Rue du Comte de Flandre,1 - Graaf van Vlaanderenstraat,nl
2 - Rue Sainte-Marie,2 - Rue Sainte-Marie,fr
2 - Rue Sainte-Marie,2 - Sint-Mariastraat,nl
1 - Place des Étangs Noirs,1 - Place des Étangs Noirs,fr
1 - Place des Étangs Noirs,1 - Zwarte Vijversplein,nl
2 - Chaussée de Gand,2 - Chaussée de Gand,fr
2 - Chaussée de Gand,2 - Gentsesteenweg,nl
1 - Rue du Luxembourg,1 - Rue du Luxembourg,fr
1 - Rue du Luxembourg,1 - Luxemburgstraat,nl
2 - Rue Montoyer,2 - Rue Montoyer,fr
2 - Rue Montoyer,2 - Montoyerstraat,nl
1 - Chaussée d'Ixelles,1 - Chaussée d'Ixelles,fr
1 - Chaussée d'Ixelles,1 - Elsensesteenweg,nl
2 - Avenue de la Toison d'Or,2 - Avenue de la Toison d'Or,fr
2 - Avenue de la Toison d'Or,2 - Gulden-Vlieslaan,nl
3 - Boulevard de Waterloo,3 - Boulevard de Waterloo,fr
3 - Boulevard de Waterloo,3 - Waterloolaan,nl
4 - Boulevard du Régent,4 - Boulevard du Régent,fr
4 - Boulevard du Régent,4 - Regentlaan,nl
5 - Place du Champ de Mars,5 - Place du Champ de Mars,fr
5 - Place du Champ de Mars,5 - Marsveldplein,nl
6 - Square du Bastion,6 - Square du Bastion,fr
6 - Square du Bastion,6 - Bolwerksquare,nl
1 - Avenue Louise,1 - Avenue Louise,fr
1 - Avenue Louise,1 - Louizalaan,nl
2 - Avenue Louise,2 - Avenue Louise,fr
2 - Avenue Louise,2 - Louizalaan,nl
4 - Boulevard de Waterloo,4 - Boulevard de Waterloo,fr
4 - Boulevard de Waterloo,4 - Waterloolaan,nl
1 - Boulevard de Waterloo,1 - Boulevard de Waterloo,fr
1 - Boulevard de Waterloo,1 - Waterloolaan,nl
3 - Avenue Henri Jaspar,3 - Avenue Henri Jaspar,fr
3 - Avenue Henri Jaspar,3 - Henri Jasparlaan,nl
1 - Rue César de Paepe,1 - Rue César de Paepe,fr
1 - Rue César de Paepe,1 - César Depaepestraat,nl
2 - Boulevard du Midi,2 - Boulevard du Midi,fr
2 - Boulevard du Midi,2 - Zuidlaan,nl
3 - Chaussée de Forest,3 - Chaussée de Forest,fr
3 - Chaussée de Forest,3 - Vorstse Steenweg,nl
4 - Avenue de la Porte de Hal,4 - Avenue de la Porte de Hal,fr
4 - Avenue de la Porte de Hal,4 - Hallepoortlaan,nl
1 - Avenue Fonsny,1 - Avenue Fonsny,fr
1 - Avenue Fonsny,1 - Fonsnylaan,nl
2 - Gare SNCB,2 - Gare SNCB,fr
2 - Gare SNCB,2 - Station NMBS Brussel-Zuid,nl
6 - Boulevard de l'Europe,6 - Boulevard de l'Europe,fr
6 - Boulevard de l'Europe,6 - Europalaan,nl
7 - Avenue Fonsny,7 - Avenue Fonsny,fr
7 - Avenue Fonsny,7 - Fonsnylaan,nl
1 - Rue de la Clinique,1 - Rue de la Clinique,fr
1 - Rue de la Clinique,1 - Kliniekstraat,nl
2 - Chaussée de Mons,2 - Chaussée de Mons,fr
2 - Chaussée de Mons,2 - Bergensesteenweg,nl
1 - Rue Léon Delacroix,1 - Rue Léon Delacroix,fr
1 - Rue Léon Delacroix,1 - Léon Delacroixstraat,nl
3 - Quai Fernand Demets,3 - Quai Fernand Demets,fr
3 - Quai Fernand Demets,3 - Fernand Demetskaai,nl
4 - Quai de l'Industrie,4 - Quai de l'Industrie,fr
4 - Quai de l'Industrie,4 - Nijverheidskaai,nl
5 - Place Louise,5 - Place Louise,fr
5 - Place Louise,5 - Louizaplein,nl
1 - Place Madou,1 - Place Madou,fr
1 - Place Madou,1 - Madouplein,nl
2 - Boulevard Bischoffsheim,2 - Boulevard Bischoffsheim,fr
2 - Boulevard Bischoffsheim,2 - Bischoffsheimlaan,nl
3 - Rue des Cultes,3 - Rue des Cultes,fr
3 - Rue des Cultes,3 - Eredienststraat,nl
4 - Place Madou,4 - Place Madou,fr
4 - Place Madou,4 - Madouplein,nl
1 - Boulevard du Jardin Botanique,1 - Boulevard du Jardin Botanique,fr
1 - Boulevard du Jardin Botanique,1 - Kruidtuinlaan,nl
2 - Boulevard Adolphe Max,2 - Boulevard Adolphe Max,fr
2 - Boulevard Adolphe Max,2 - Adolphe Maxlaan,nl
3 - Boulevard Adolphe Max,3 - Boulevard Adolphe Max,fr
3 - Boulevard Adolphe Max,3 - Adolphe Maxlaan,nl
1 - City 2,1 - City 2,fr
1 - City 2,1 - City 2,nl
8 - Place Charles Rogier,8 - Place Charles Rogier,fr
8 - Place Charles Rogier,8 - Karel Rogierplein,nl
7 - Place Charles Rogier,7 - Place Charles Rogier,fr
7 - Place Charles Rogier,7 - Karel Rogierplein,nl
4 - Avenue du Boulevard,4 - Avenue du Boulevard,fr
4 - Avenue du Boulevard,4 - Bolwerklaan,nl
9 - Manhattan center,9 - Manhattan center,fr
9 - Manhattan center,9 - Manhattan Center,nl
1 - Boulevard Baudouin,1 - Boulevard Baudouin,fr
1 - Boulevard Baudouin,1 - Boudewijnlaan,nl
2 - Chaussée d'Anvers,2 - Chaussée d'Anvers,fr
2 - Chaussée d'Anvers,2 - Antwerpsesteenweg,nl
3 - Porte d'Anvers,3 - Porte d'Anvers,fr
3 - Porte d'Anvers,3 - Antwerpsepoort,nl
4 - Boulevard d'Anvers,4 - Boulevard d'Anvers,fr
4 - Boulevard d'Anvers,4 - Antwerpselaan,nl
5 - Boulevard d'Anvers,5 - Boulevard d'Anvers,fr
5 - Boulevard d'Anvers,5 - Antwerpselaan,nl
6 - Parc Maximilien,6 - Parc Maximilien,fr
6 - Parc Maximilien,6 - Maximiliaanpark,nl
1 - Boulevard Léopold II,1 - Boulevard Léopold II,fr
1 - Boulevard Léopold II,1 - Leopold II-laan,nl
2 - Boulevard Léopold II,2 - Boulevard Léopold II,fr
2 - Boulevard Léopold II,2- Leopold II-laan,nl
2 - Rue de l'Armistice,2 - Rue de l'Armistice,fr
2 - Rue de l'Armistice,2 - Wapenstilstandstraat,nl
3 - Rue de l'Armistice,3 - Rue de l'Armistice,fr
3 - Rue de l'Armistice,3 - Wapenstilstandstraat,nl
4 - Boulevard Léopold II,4 - Boulevard Léopold II,fr
4 - Boulevard Léopold II,4 - Leopold II-laan,nl
6 - Place Simonis,6 - Place Simonis,fr
6 - Place Simonis,6 - Eugène Simonisplein,nl
1 - Gare SNCB,1 - Gare SNCB,fr
1 - Gare SNCB,1 - Station NMBS Brussel-Noord,nl
1 - Boulevard Anspach,1 - Boulevard Anspach,fr
1 - Boulevard Anspach,1 - Anspachlaan,nl
2 - Boulevard Anspach,2 - Boulevard Anspach,fr
2 - Boulevard Anspach,2 - Anspachlaan,nl
3 - Bourse,3 - Bourse,fr
3 - Bourse,3 - Beurs,nl
4 - Bourse,4 - Bourse,fr
4 - Bourse,4 - Beurs,nl
5 - Boulevard Anspach,5 - Boulevard Anspach,fr
5 - Boulevard Anspach,5 - Anspachlaan,nl
6 - Boulevard Anspach,6 - Boulevard Anspach,fr
6 - Boulevard Anspach,6 - Anspachlaan,nl
7 - Boulevard Anspach,7 - Boulevard Anspach,fr
7 - Boulevard Anspach,7 - Anspachlaan,nl
8 - Boulevard Anspach,8 - Boulevard Anspach,fr
8 - Boulevard Anspach,8 - Anspachlaan,nl
9 - Bourse,9 - Bourse,fr
9 - Bourse,9 - Beurs,nl
10 - Bourse,10 - Bourse,fr
10 - Bourse,10 - Beurs,nl
11 - Place de la Bourse,11 - Place de la Bourse,fr
11 - Place de la Bourse,11 - Beursplein,nl
12 - Boulevard Anspach,12 - Boulevard Anspach,fr
12 - Boulevard Anspach,12 - Anspachlaan,nl
1 - Place Anneessens,1 - Place Anneessens,fr
1 - Place Anneessens,1 - Anneessensplein,nl
2 - Place Anneessens,2 - Place Anneessens,fr
2 - Place Anneessens,2 - Anneessensplein,nl
3 - Rue de Tournai,3 - Rue de Tournai,fr
3 - Rue de Tournai,3 - Doornikstraat,nl
4 - Boulevard Maurice Lemonnier,4 - Boulevard Maurice Lemonnier,fr
4 - Boulevard Maurice Lemonnier,4 - Maurice Lemonnierlaan,nl
5 - Place Anneessens,5 - Place Anneessens,fr
5 - Place Anneessens,5 - Anneessensplein,nl
6 - Place Anneessens,6 - Place Anneessens,fr
6 - Place Anneessens,6 - Anneessensplein,nl
1 - Boulevard Maurice Lemonnier,1 - Boulevard Maurice Lemonnier,fr
1 - Boulevard Maurice Lemonnier,1 - Maurice Lemonnierlaan,nl
1 - Parvis de Saint-Gilles,1 - Parvis de Saint-Gilles,fr
1 - Parvis de Saint-Gilles,1 - Sint-Gillisvoorplein,nl
2 - Rue Hôtel des Monnaies,2 - Rue Hôtel des Monnaies,fr
2 - Rue Hôtel des Monnaies,2 - Munthofstraat,nl
1 - Chaussée de Waterloo,1 - Chaussée de Waterloo,fr
1 - Chaussée de Waterloo,1 - Waterloosesteenweg,nl
2 - Chaussée de Waterloo,2 - Chaussée de Waterloo,fr
2 - Chaussée de Waterloo,2 - Waterloosesteenweg,nl
1 - Avenue Jupiter,1 - Avenue Jupiter,fr
1 - Avenue Jupiter,1 - Jupiterlaan,nl
2 - Avenue Besme,2 - Avenue Besme,fr
2 - Avenue Besme,2 - Besmelaan,nl
3 - Avenue Albert,3 - Avenue Albert,fr
3 - Avenue Albert,3 - Albertlaan,nl
1 - Square Vergote,1 - Square Vergote,fr
1 - Square Vergote,1 - Vergoteplein,nl
2 - Square Vergote,2 - Square Vergote,fr
2 - Square Vergote,2 - Vergoteplein,nl
3 - Boulevard Brand Whitlock,3 - Boulevard Brand Whitlock,fr
3 - Boulevard Brand Whitlock,3 - Brand Whitlocklaan,nl
4 - Boulevard Brand Whitlock,4 - Boulevard Brand Whitlock,fr
4 - Boulevard Brand Whitlock,4 - Brand Whitlocklaan,nl
1 - Boulevard Auguste Reyers,1 - Boulevard Auguste Reyers,fr
1 - Boulevard Auguste Reyers,1 - Auguste Reyerslaan,nl
2 - Boulevard Auguste Reyers,2 - Boulevard Auguste Reyers,fr
2 - Boulevard Auguste Reyers,2 - Auguste Reyerslaan,nl
1 - Boulevard Saint-Michel,1 - Boulevard Saint-Michel,fr
1 - Boulevard Saint-Michel,1 - Sint-Michielslaan,nl
2 - Rue Charles Legrelle,2 - Rue Charles Legrelle,fr
2 - Rue Charles Legrelle,2 - Charles Legrellestraat,nl
3 - Rue Charles Legrelle,3 - Rue Charles Legrelle,fr
3 - Rue Charles Legrelle,3 - Charles Legrellestraat,nl
4 - Rue Père E. Devroye,4 - Rue Père E. Devroye,fr
4 - Rue Père E. Devroye,4 - Pater Eudore Devroyestraat,nl
5 - Avenue Boileau,5 - Avenue Boileau,fr
5 - Avenue Boileau,5 - Boileaulaan,nl
1 - Route de Lennik,1 - Route de Lennik,fr
1 - Route de Lennik,1 - Lenniksebaan,nl
2 - Route de Lennik,2 - Route de Lennik,fr
2 - Route de Lennik,2 - Lenniksebaan,nl
3 - Hôpital Erasme,3 - Hôpital Erasme,fr
3 - Hôpital Erasme,3 - Erasmus Ziekenhuis,nl
1 - Boulevard Josse Leemans,1 - Boulevard Josse Leemans,fr
1 - Boulevard Josse Leemans,1 - Josse Leemanslaan,nl
1 - Chaussée de Mons,1 - Chaussée de Mons,fr
1 - Chaussée de Mons,1 - Bergensesteenweg,nl
2 - Parking CERIA,2 - Parking CERIA,fr
2 - Parking CERIA,2 - Parking CERIA,nl
1 - Place Bizet,1 - Place Bizet,fr
1 - Place Bizet,1 - Bizetplein,nl
1 - Avenue Gounod,1 - Avenue Gounod,fr
1 - Avenue Gounod,1 - Gounodlaan,nl
2 - Place Verdi,2 - Place Verdi,fr
2 - Place Verdi,2 - Verdiplein,nl
1 - Cours Saint-Guidon,1 - Cours Saint-Guidon,fr
1 - Cours Saint-Guidon,1 - Sint-Guidocorso,nl
2 - Cours Saint-Guidon,2 - Cours Saint-Guidon,fr
2 - Cours Saint-Guidon,2 - Sint-Guidocorso,nl
1 - Square E. Vander Bruggen,1 - Square E. Vander Bruggen,fr
1 - Square E. Vander Bruggen,1 - Emile Vander Bruggensquare,nl
2 - Place du Repos,2 - Place du Repos,fr
2 - Place du Repos,2 - Rustplein,nl
1 - Avenue Norbert Gille,1 - Avenue Norbert Gille,fr
1 - Avenue Norbert Gille,1 - Norbert Gillelaan,nl
2 - Avenue Norbert Gille,2 - Avenue Norbert Gille,fr
2 - Avenue Norbert Gille,2 - Norbert Gillelaan,nl
3 - Boulevard Jules Graindor,3 - Boulevard Jules Graindor,fr
3 - Boulevard Jules Graindor,3 - Jules Graindorlaan,nl
4 - Boulevard Jules Graindor,4 - Boulevard Jules Graindor,fr
4 - Boulevard Jules Graindor,4 - Jules Graindorlaan,nl
1 - Avenue Joseph Baeck,1 - Avenue Joseph Baeck,fr
1 - Avenue Joseph Baeck,1 - Joseph Baecklaan,nl
5 - Rue Verheyden,5 - Rue Verheyden,fr
5 - Rue Verheyden,5 - Verheydenstraat,nl
6 - Chaussée de Ninove,6 - Chaussée de Ninove,fr
6 - Chaussée de Ninove,6 - Ninoofsesteenweg,nl
1 - Rue Dubois-Thorn,1 - Rue Dubois-Thorn,fr
1 - Rue Dubois-Thorn,1 - Dubois-Thornstraat,nl
2 - Rue Alphonse Vandenpeereboom,2 - Rue Alphonse Vandenpeereboom,fr
2 - Rue Alphonse Vandenpeereboom,2 - Alphonse Vandenpeereboomstraat,nl
1 - Chaussée de Gand,1 - Chaussée de Gand,fr
1 - Chaussée de Gand,1- Gentsesteenweg,nl
2 - Avenue Mahatma Gandhi,2 - Avenue Mahatma Gandhi,fr
2 - Avenue Mahatma Gandhi,2 - Mahatma Gandhilaan,nl
1 - Boulevard Belgica,1 - Boulevard Belgica,fr
1 - Boulevard Belgica,1 - Belgicalaan,nl
2 - Boulevard Belgica,2 - Boulevard Belgica,fr
2 - Boulevard Belgica,2 - Belgicalaan,nl
1 - Rue Charles Demeer,1 - Rue Charles Demeer,fr
1 - Rue Charles Demeer,1 - Charles Demeerstraat,nl
1 - Rue Léopold I,1 - Rue Léopold I,fr
1 - Rue Léopold I,1 - Leopold I-straat,nl
2 - Place Emile Bockstael,2 - Place Emile Bockstael,fr
2 - Place Emile Bockstael,2 - Emile Bockstaelplein,nl
3 - Boulevard Emile Bockstael,3 - Boulevard Emile Bockstael,fr
3 - Boulevard Emile Bockstael,3 - Emile Bockstaelplein,nl
4 - Rue du Champ de la Couronne,4 - Rue du Champ de la Couronne,fr
4 - Rue du Champ de la Couronne,4 - Kroonveldstraat,nl
5 - Rue des Artistes,5 - Rue des Artistes,fr
5 - Rue des Artistes,5 - Kunstenaarsstraat,nl
1 - Boulevard de Smet de Naeyer,1 - Boulevard de Smet de Naeyer,fr
1 - Boulevard de Smet de Naeyer,1 - de Smet de Naeyerlaan,nl
4 - Avenue Houba-de Strooper,4 - Avenue Houba-de Strooper,fr
4 - Avenue Houba-de Strooper,4 - Houba de Strooperlaan,nl
3 - Boulevard de Smet de Naeyer,3 - Boulevard de Smet de Naeyer,fr
3 - Boulevard de Smet de Naeyer,3 - de Smet de Naeyerlaan,nl
2 - Avenue Houba-de Strooper,2 - Avenue Houba-de Strooper,fr
2 - Avenue Houba-de Strooper,2 - Houba de Strooperlaan,nl
1 - Avenue Houba-de Strooper,1 - Avenue Houba-de Strooper,fr
1 - Avenue Houba-de Strooper,1 - Houba de Strooperlaan,nl
2 - Rue du Heysel,2 - Rue du Heysel,fr
2 - Rue du Heysel,2 - Heizelstraat,nl
1 - Avenue Impératrice Charlotte,1 - Avenue Impératrice Charlotte,fr
1 - Avenue Impératrice Charlotte,1 - Keizerin Charlottelaan,nl
2 - Avenue des Athlètes,2 - Avenue des Athlètes,fr
2 - Avenue des Athlètes,2 - Atletenlaan,nl
3 - Esplanade,3 - Esplanade,fr
3 - Esplanade,3 - Esplanade,nl
4 - Esplanade,4 - Esplanade,fr
4 - Esplanade,4 - Esplanade,nl
2 - Avenue Houba de Strooper,2 - Avenue Houba de Strooper,fr
2 - Avenue Houba de Strooper,2 - Houba de Strooperlaan,nl
3 - Avenue des Citronniers,3 - Avenue des Citronniers,fr
3 - Avenue des Citronniers,3 - Citroenbomenlaan,nl
"""



"""
interact async with the opendata api of the Belgian STIB MIVB public transport company
"""

import csv
import re
from io import StringIO

import aiohttp
import yarl

from .routes import LINE_CSV_FILE, TRANSLATIONS_CSV_FILE

URL = "https://opendata-api.stib-mivb.be/"  # pragma: no mutate
ROUTES_URL = (
    "https://openmobilitydata-data.s3-us-west-1.amazonaws.com/"  # pragma: no mutate
    "public/feeds/societe-des-transports-intercommunaux-de-"  # pragma: no mutate
    "bruxelles/527/latest/download/routes.txt"  # pragma: no mutate
)  # pragma: no mutate
TRANSLATIONS_URL = (
    "https://openmobilitydata-data.s3-us-west-1.amazonaws.com/"  # pragma: no mutate
    "public/feeds/societe-des-transports-intercommunaux-de-"  # pragma: no mutate
    "bruxelles/527/latest/download/translations.txt"  # pragma: no mutate
)  # pragma: no mutate


def base_url():
    """ return the base url for the api """
    return URL + "{}/{}"


METHODS = {
    "vehicle_position": "OperationMonitoring/4.0/VehiclePositionByLine",
    "waiting_time": "OperationMonitoring/4.0/PassingTimeByPoint",
    "message_by_line": "OperationMonitoring/4.0/MessageByLine",
    "stops_by_line": "NetworkDescription/1.0/PointByLine",
    "point_detail": "NetworkDescription/1.0/PointDetail",
}


class ODStibMivb:
    """Interface with Stib-Mivb Open Data API"""

    def __init__(self, access_token, session=None):
        self.access_token = access_token
        self._session = session
        self._gtfs_line_data = None
        self._gtfs_translation_data = None

    @property
    def access_token(self):
        """The access code to acces the api"""
        return self.__access_token

    @access_token.setter
    def access_token(self, value):
        value = value.lower()
        if re.fullmatch("[a-f0-9]{32}", value):
            # pylint: disable=W0201
            self.__access_token = value
            self.__header = {"Authorization": "Bearer " + self.access_token}
        else:
            raise ValueError("invalid format for access token")

    @property
    def header(self):
        """http header in which te access code will be set"""
        return self.__header

    async def get_gtfs_line_data(self, id_):
        """get data from gtfs data file"""
        if self._gtfs_line_data is None:
            self._gtfs_line_data = await self.set_gtfs_line_data()
        try:
            return self._gtfs_line_data[str(id_)]
        except KeyError:
            raise ValueError("unknown line id")

    async def get_gtfs_translation_data(self, trans_id):
        """get data from gtfs translation file"""
        if self._gtfs_translation_data is None:
            self._gtfs_translation_data = await self.set_gtfs_translation_data()
        try:
            return self._gtfs_translation_data[trans_id]
        except KeyError:
            raise ValueError("unknown translation id")

    async def set_gtfs_translation_data(self):
        """
        get the gtfs data. Either from the server
        or from the embedded csv file if that fails
        """
        try:
            if self._session is None:
                async with aiohttp.ClientSession() as session:
                    data = await self.get_gtfs_response(
                        session, TRANSLATIONS_URL
                    )  # pragma: no mutate
            else:
                data = await self.get_gtfs_response(self._session, TRANSLATIONS_URL)
            return extract_gtfs_translation_data(data.decode())
        except HttpException:
            return extract_gtfs_translation_data(TRANSLATIONS_CSV_FILE)

    async def set_gtfs_line_data(self):
        """
        get the gtfs data. Either from the server
        or from the embedded csv file if that fails
        """
        try:
            if self._session is None:
                async with aiohttp.ClientSession() as session:
                    data = await self.get_gtfs_response(session)  # pragma: no mutate
            else:
                data = await self.get_gtfs_response(self._session, ROUTES_URL)
            return extract_gtfs_line_data(data.decode())
        except HttpException:
            return extract_gtfs_line_data(LINE_CSV_FILE)

    async def get_gtfs_response(self, session, url):
        """
        get the gtfs data from the remote server
        """
        async with session.get(url) as response:
            if response.status == 200:
                data = await response.content.read()
            else:
                code = response.status  # pragma: no mutate
                message = f"Unexpected status code {code}."  # pragma: no mutate
                raise HttpException(message, await response.text(), response.status)
            return data

    async def do_request(self, method, id_, *ids):
        """
        Create a session if needed and do the API request
        """
        if method not in METHODS:
            raise ValueError("this method does not exist")

        if self._session is None:
            async with aiohttp.ClientSession() as session:
                return await self.get_response_unlimited(session, method, id_, *ids)
        else:
            return await self.get_response_unlimited(self._session, method, id_, *ids)

    async def get_response_unlimited(self, session, method, *ids):
        """
        if needed split up the api request in multiple 10 argument requests
        """
        response_unlimited = {}
        i = 0
        while i < len(ids):
            url = yarl.URL(
                base_url().format(
                    METHODS[method], "%2C".join(str(e) for e in ids[i : i + 10])
                ),
                # we need this here, but doesn't make a difference with our mock app
                # so mutmut complains :(
                encoded=True,  # pragma: no mutate
            )

            response = await self.get_response(session, url)
            assert len(response.keys()) == 1
            for key in response.keys():
                if key in response_unlimited.keys():
                    response_unlimited[key].extend(response[key])
                else:
                    response_unlimited[key] = response[key]
            i = i + 10
        return response_unlimited

    async def get_response(self, session, url):
        """
        Do the actual api request
        """
        async with session.get(url, headers=self.header) as response:
            if response.status == 200:
                try:
                    json_data = await response.json()
                except ValueError as exception:
                    message = "Server gave incorrect data"
                    raise Exception(message) from exception

            elif response.status == 401:
                message = "401: Acces token might be incorrect or expired"
                raise HttpException(message, await response.text(), response.status)

            elif response.status == 403:
                message = "403: incorrect API request"
                raise HttpException(message, await response.text(), response.status)

            else:
                message = f"Unexpected status code {response.status}."
                raise HttpException(message, await response.text(), response.status)

            return json_data

    async def get_vehicle_position(self, id_, *ids):
        """do the vehicle position api request"""
        return await self.do_request("vehicle_position", id_, *ids)

    async def get_waiting_time(self, id_, *ids):
        """do the waiting time api request"""
        return await self.do_request("waiting_time", id_, *ids)

    async def get_message_by_line(self, id_, *ids):
        """do the message by line api request"""
        return await self.do_request("message_by_line", id_, *ids)

    async def get_message_by_line_with_point_detail(self, id_, *ids):
        """
        do the message by line api request,
        and get the point id of the mentioned stops in the response
        """
        response = await self.do_request("message_by_line", id_, *ids)
        for line in response["messages"]:
            point_ids = [id_["id"] for id_ in line["points"]]
            point_details = await self.get_point_detail(*point_ids)
            line["points"] = point_details["points"]
        return response

    async def get_stops_by_line(self, id_, *ids):
        """do the stops by line api request"""
        return await self.do_request("stops_by_line", id_, *ids)

    async def get_point_detail(self, id_, *ids):
        """do the point detail api request"""
        return await self.do_request("point_detail", id_, *ids)

    async def get_line_long_name(self, id_):
        """get the long name from the static gtfs file"""
        tmp = await self.get_gtfs_line_data(str(id_))
        return tmp[0]

    async def get_line_type(self, id_):
        """get the route type from the static gtfs file"""
        tmp = await self.get_gtfs_line_data(str(id_))
        return tmp[1]

    async def get_line_color(self, id_):
        """get the route color from the static gtfs file"""
        tmp = await self.get_gtfs_line_data(str(id_))
        return tmp[2]

    async def get_line_text_color(self, id_):
        """get the route text color from the static gtfs file"""
        tmp = await self.get_gtfs_line_data(str(id_))
        return tmp[3]

    async def get_translation_fr(self, trans_id):
        """get the route text color from the static gtfs file"""
        return await self.get_gtfs_translation_data((trans_id, "fr"))

    async def get_translation_nl(self, trans_id):
        """get the route text color from the static gtfs file"""
        return await self.get_gtfs_translation_data((trans_id, "nl"))


def extract_gtfs_line_data(data):
    """extract the gtfs line csv file and put it in a dict"""
    gtfs_line_data = {}
    buffer = StringIO(data)
    reader = csv.DictReader(buffer, delimiter=",")
    for row in reader:
        gtfs_line_data[row["route_short_name"]] = (
            row["route_long_name"],
            row["route_type"],
            row["route_color"],
            row["route_text_color"],
        )
    return gtfs_line_data


def extract_gtfs_translation_data(data):
    """extract the gtfs translation csv file and put it in a dict"""
    gtfs_translation_data = {}
    buffer = StringIO(data)
    reader = csv.DictReader(buffer, delimiter=",")
    for row in reader:
        gtfs_translation_data[(row["trans_id"], row["lang"])] = row["translation"]
    return gtfs_translation_data


class HttpException(Exception):
    """ HTTP exception class with message text, and status code"""

    def __init__(self, message, text, status_code):

        super().__init__(message)

        self.status_code = status_code
        self.text = text
